// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://ftmscan.com/address/0x9abf798f5314BFd793A9E57A654BEd35af4A1D60
export const PARASWAP_FEE_CLAIMER = '0x9abf798f5314BFd793A9E57A654BEd35af4A1D60';

export const CHAIN_ID = 250;
