// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://snowtrace.io/address/0x9abf798f5314BFd793A9E57A654BEd35af4A1D60
export const PARASWAP_FEE_CLAIMER = '0x9abf798f5314BFd793A9E57A654BEd35af4A1D60';

// https://snowtrace.io/address/0xB4e496f70602fE2AC6Ae511D028BA4D194773B29
export const TRANSPARENT_PROXY_FACTORY = '0xB4e496f70602fE2AC6Ae511D028BA4D194773B29';

// https://snowtrace.io/address/0xD3cF979e676265e4f6379749DECe4708B9A22476
export const PROXY_ADMIN = '0xD3cF979e676265e4f6379749DECe4708B9A22476';

// https://snowtrace.io/address/0x3b56998Ec06477704622ca8e2eA1b4db134cec32
export const CREATE_3_FACTORY = '0x3b56998Ec06477704622ca8e2eA1b4db134cec32';

// https://snowtrace.io/address/0x06d958772304e7220fc3E463756CE01Ed0D24db2
export const AAVE_CL_ROBOT_OPERATOR = '0x06d958772304e7220fc3E463756CE01Ed0D24db2';

// https://snowtrace.io/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
export const PROTOCOL_GUARDIAN = '0x56C1a4b54921DEA9A344967a8693C7E661D72968';

// https://snowtrace.io/address/0xA065d5A299E618CD84a87641d5eEbC7916Fdf32E
export const AAVE_MERKLE_DISTRIBUTOR = '0xA065d5A299E618CD84a87641d5eEbC7916Fdf32E';

export const CHAIN_ID = 43114;
