// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscMetis {
  // https://explorer.metis.io/address/0x1dad86dC5990BCE5bFe3A150A4E0ece990d6EBcB
  address internal constant TRANSPARENT_PROXY_FACTORY = 0x1dad86dC5990BCE5bFe3A150A4E0ece990d6EBcB;

  // https://explorer.metis.io/address/0x1CabD986cBAbDf12E00128DFf03C80ee62C4fd97
  address internal constant PROXY_ADMIN = 0x1CabD986cBAbDf12E00128DFf03C80ee62C4fd97;

  // https://explorer.metis.io/address/0x2e649f6b54B07E210b31c9cC2eB8a0d5997c3D4A
  address internal constant CREATE_3_FACTORY = 0x2e649f6b54B07E210b31c9cC2eB8a0d5997c3D4A;

  // https://explorer.metis.io/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
  address internal constant PROTOCOL_GUARDIAN = 0x56C1a4b54921DEA9A344967a8693C7E661D72968;

  // https://explorer.metis.io/address/0x8EC77963068474a45016938Deb95E603Ca82a029
  address internal constant LEGACY_BRIDGE_EXECUTOR = 0x8EC77963068474a45016938Deb95E603Ca82a029;
}
