import {ConfigFile} from '../../generator/types';
export const config: ConfigFile = {
  rootOptions: {
    author: 'BGD Labs @bgdlabs',
    pools: [
      'AaveV3Ethereum',
      'AaveV3EthereumLido',
      'AaveV3EthereumEtherFi',
      'AaveV3Polygon',
      'AaveV3Avalanche',
      'AaveV3Optimism',
      'AaveV3Arbitrum',
      'AaveV3Metis',
      'AaveV3Base',
      'AaveV3Gnosis',
      'AaveV3Scroll',
      'AaveV3BNB',
      'AaveV3ZkSync',
    ],
    title: '3.2 patch for legacy periphery',
    shortName: '32PatchForLegacyPeriphery',
    date: '20241010',
    discussion: 'https://governance.aave.com/t/bgd-technical-maintenance-proposals/15274/45',
    snapshot: '',
    votingNetwork: 'POLYGON',
  },
  poolOptions: {
    AaveV3Ethereum: {configs: {OTHERS: {}}, cache: {blockNumber: 20934650}},
    AaveV3EthereumLido: {configs: {OTHERS: {}}, cache: {blockNumber: 20934651}},
    AaveV3EthereumEtherFi: {configs: {OTHERS: {}}, cache: {blockNumber: 20934651}},
    AaveV3Polygon: {configs: {OTHERS: {}}, cache: {blockNumber: 62862189}},
    AaveV3Avalanche: {configs: {OTHERS: {}}, cache: {blockNumber: 51598199}},
    AaveV3Optimism: {configs: {OTHERS: {}}, cache: {blockNumber: 126478907}},
    AaveV3Arbitrum: {configs: {OTHERS: {}}, cache: {blockNumber: 262322324}},
    AaveV3Metis: {configs: {OTHERS: {}}, cache: {blockNumber: 18682620}},
    AaveV3Base: {configs: {OTHERS: {}}, cache: {blockNumber: 20883624}},
    AaveV3Gnosis: {configs: {OTHERS: {}}, cache: {blockNumber: 36432334}},
    AaveV3Scroll: {configs: {OTHERS: {}}, cache: {blockNumber: 10034555}},
    AaveV3BNB: {configs: {OTHERS: {}}, cache: {blockNumber: 42992248}},
    AaveV3ZkSync: {configs: {OTHERS: {}}, cache: {blockNumber: 46260823}},
  },
};
