// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
import {IGovernanceCore, IPayloadsControllerCore, IDataWarehouse, IVotingStrategy} from './GovernanceV3.sol';

library GovernanceV3Mumbai {
  // https://mumbai.polygonscan.com/address/0xe521cB5e23DbF8248c0B0C3C2503feA3C4c7Caff
  address internal constant CROSS_CHAIN_CONTROLLER = 0xe521cB5e23DbF8248c0B0C3C2503feA3C4c7Caff;

  // https://mumbai.polygonscan.com/address/0x05D0215cFC8D4B726085ADDb1ce43bC5C70f9D8f
  address internal constant VOTING_MACHINE = 0x05D0215cFC8D4B726085ADDb1ce43bC5C70f9D8f;

  // https://mumbai.polygonscan.com/address/0x92041C9904d1F0b8100D1d7e01B760d2cF1Fb426
  IPayloadsControllerCore internal constant PAYLOADS_CONTROLLER =
    IPayloadsControllerCore(0x92041C9904d1F0b8100D1d7e01B760d2cF1Fb426);

  // https://mumbai.polygonscan.com/address/0x858859CCDDa608941bB64D260a836298c49Ff0C7
  address internal constant EXECUTOR_LVL_1 = 0x858859CCDDa608941bB64D260a836298c49Ff0C7;

  // https://mumbai.polygonscan.com/address/0x2FD0ea3cF58cB9cD25c2a186E643629198A37600
  IVotingStrategy internal constant VOTING_STRATEGY =
    IVotingStrategy(0x2FD0ea3cF58cB9cD25c2a186E643629198A37600);

  // https://mumbai.polygonscan.com/address/0x1F780a6E860792E59F2160b1E9E503bFF8c58Cb1
  IDataWarehouse internal constant DATA_WAREHOUSE =
    IDataWarehouse(0x1F780a6E860792E59F2160b1E9E503bFF8c58Cb1);
}
