// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://polygonscan.com/address/0x1C2BA5b8ab8e795fF44387ba6d251fa65AD20b36
export const AAVE_POL_ETH_BRIDGE = '0x1C2BA5b8ab8e795fF44387ba6d251fa65AD20b36';

// https://polygonscan.com/address/0x9abf798f5314BFd793A9E57A654BEd35af4A1D60
export const PARASWAP_FEE_CLAIMER = '0x9abf798f5314BFd793A9E57A654BEd35af4A1D60';

// https://polygonscan.com/address/0xB4e496f70602fE2AC6Ae511D028BA4D194773B29
export const TRANSPARENT_PROXY_FACTORY = '0xB4e496f70602fE2AC6Ae511D028BA4D194773B29';

// https://polygonscan.com/address/0xD3cF979e676265e4f6379749DECe4708B9A22476
export const PROXY_ADMIN = '0xD3cF979e676265e4f6379749DECe4708B9A22476';

// https://polygonscan.com/address/0x3b56998Ec06477704622ca8e2eA1b4db134cec32
export const CREATE_3_FACTORY = '0x3b56998Ec06477704622ca8e2eA1b4db134cec32';

// https://polygonscan.com/address/0xB4C212f5cD17E200019b07e6B1fDf124d35DBCf5
export const AAVE_CL_ROBOT_OPERATOR = '0xB4C212f5cD17E200019b07e6B1fDf124d35DBCf5';

// https://polygonscan.com/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
export const PROTOCOL_GUARDIAN = '0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6';

// https://polygonscan.com/address/0x7A9ff54A6eE4a21223036890bB8c4ea2D62c686b
export const AAVE_MERKLE_DISTRIBUTOR = '0x7A9ff54A6eE4a21223036890bB8c4ea2D62c686b';

// https://polygonscan.com/address/0x3Ea1eC855fBda8bA0396975eC260AD2e9B2Bc01c
export const wstETH_stETH_AGGREGATOR = '0x3Ea1eC855fBda8bA0396975eC260AD2e9B2Bc01c';

// https://polygonscan.com/address/0xeE652bbF72689AA59F0B8F981c9c90e2A8Af8d8f
export const MaticX_RATE_PROVIDER = '0xeE652bbF72689AA59F0B8F981c9c90e2A8Af8d8f';

// https://polygonscan.com/address/0xdEd6C522d803E35f65318a9a4d7333a22d582199
export const stMATIC_RATE_PROVIDER = '0xdEd6C522d803E35f65318a9a4d7333a22d582199';

// https://polygonscan.com/address/0xdc9A35B16DB4e126cFeDC41322b3a36454B1F772
export const LEGACY_BRIDGE_EXECUTOR = '0xdc9A35B16DB4e126cFeDC41322b3a36454B1F772';

export const CHAIN_ID = 137;
