// https://zkevm.polygonscan.com/address/0xed7e0874526B9BB9E36C7e9472ed7ed324CEeE3B
export const CROSS_CHAIN_CONTROLLER = '0xed7e0874526B9BB9E36C7e9472ed7ed324CEeE3B';

// IPayloadsControllerCore https://zkevm.polygonscan.com/address/0xa2d22795E0D85D4Cb14Cbb14Df7bb8fec1016615
export const PAYLOADS_CONTROLLER = '0xa2d22795E0D85D4Cb14Cbb14Df7bb8fec1016615';

// https://zkevm.polygonscan.com/address/0xF1c11BE0b4466728DDb7991A0Ac5265646ec9672
export const PC_DATA_HELPER = '0xF1c11BE0b4466728DDb7991A0Ac5265646ec9672';

// https://zkevm.polygonscan.com/address/0xe59470B3BE3293534603487E00A44C72f2CD466d
export const EXECUTOR_LVL_1 = '0xe59470B3BE3293534603487E00A44C72f2CD466d';

export const CHAIN_ID = 1101;
