// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://sepolia.arbiscan.io/address/0x43A8B7eC945a12a3Acb127B77ede19bd73ad76f8
export const TRANSPARENT_PROXY_FACTORY = '0x43A8B7eC945a12a3Acb127B77ede19bd73ad76f8';

// https://sepolia.arbiscan.io/address/0xCB5B3ca20603231945dC5731C33E7f7F7679Ea89
export const PROXY_ADMIN = '0xCB5B3ca20603231945dC5731C33E7f7F7679Ea89';

// https://sepolia.arbiscan.io/address/0xb13Cfa6f8B2Eed2C37fB00fF0c1A59807C585810
export const GHO_TOKEN = '0xb13Cfa6f8B2Eed2C37fB00fF0c1A59807C585810';

export const CHAIN_ID = 421614;
