// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscPolygonZkEvm {
  // https://zkevm.polygonscan.com/address/0xAe940e61E9863178b71500c9B5faE2a04Da361a1
  address internal constant PARASWAP_FEE_CLAIMER = 0xAe940e61E9863178b71500c9B5faE2a04Da361a1;

  // https://zkevm.polygonscan.com/address/0x8B6851156023f4f5A66F68BEA80851c3D905Ac93
  address internal constant TRANSPARENT_PROXY_FACTORY = 0x8B6851156023f4f5A66F68BEA80851c3D905Ac93;

  // https://zkevm.polygonscan.com/address/0x2f6571d3Eb9a4e350C68C36bCD2afe39530078E2
  address internal constant PROXY_ADMIN = 0x2f6571d3Eb9a4e350C68C36bCD2afe39530078E2;

  // https://zkevm.polygonscan.com/address/0xE2E8Badc5d50f8a6188577B89f50701cDE2D4e19
  address internal constant CREATE_3_FACTORY = 0xE2E8Badc5d50f8a6188577B89f50701cDE2D4e19;

  // https://zkevm.polygonscan.com/address/0x8C05474F1f0161F71276677De0a2d8a347583c45
  address internal constant PROTOCOL_GUARDIAN = 0x8C05474F1f0161F71276677De0a2d8a347583c45;
}
