// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// IPoolAddressesProvider https://ftmscan.com/address/0xa97684ead0e402dC232d5A977953DF7ECBaB3CDb
export const POOL_ADDRESSES_PROVIDER = '0xa97684ead0e402dC232d5A977953DF7ECBaB3CDb';

// IPool https://ftmscan.com/address/0x794a61358D6845594F94dc1DB02A252b5b4814aD
export const POOL = '0x794a61358D6845594F94dc1DB02A252b5b4814aD';

// IPoolConfigurator https://ftmscan.com/address/0x8145eddDf43f50276641b55bd3AD95944510021E
export const POOL_CONFIGURATOR = '0x8145eddDf43f50276641b55bd3AD95944510021E';

// IAaveOracle https://ftmscan.com/address/0xfd6f3c1845604C8AE6c6E402ad17fb9885160754
export const ORACLE = '0xfd6f3c1845604C8AE6c6E402ad17fb9885160754';

// https://ftmscan.com/address/0x39CB97b105173b56b5a2b4b33AD25d6a50E6c949
export const ACL_ADMIN = '0x39CB97b105173b56b5a2b4b33AD25d6a50E6c949';

// IACLManager https://ftmscan.com/address/0xa72636CbcAa8F5FF95B2cc47F3CDEe83F3294a0B
export const ACL_MANAGER = '0xa72636CbcAa8F5FF95B2cc47F3CDEe83F3294a0B';

// IPoolDataProvider https://ftmscan.com/address/0x69FA688f1Dc47d4B5d8029D5a35FB7a548310654
export const AAVE_PROTOCOL_DATA_PROVIDER = '0x69FA688f1Dc47d4B5d8029D5a35FB7a548310654';

// https://ftmscan.com/address/0xDF9e4ABdbd94107932265319479643D3B05809dc
export const POOL_IMPL = '0xDF9e4ABdbd94107932265319479643D3B05809dc';

// https://ftmscan.com/address/0xD6FA681E22306b0F4E605B979b7c9a1dFa865ade
export const POOL_CONFIGURATOR_IMPL = '0xD6FA681E22306b0F4E605B979b7c9a1dFa865ade';

// https://ftmscan.com/address/0x929EC64c34a17401F460460D4B9390518E5B473e
export const DEFAULT_INCENTIVES_CONTROLLER = '0x929EC64c34a17401F460460D4B9390518E5B473e';

// https://ftmscan.com/address/0x048f2228D7Bf6776f99aB50cB1b1eaB4D1d4cA73
export const EMISSION_MANAGER = '0x048f2228D7Bf6776f99aB50cB1b1eaB4D1d4cA73';

// ICollector https://ftmscan.com/address/0xBe85413851D195fC6341619cD68BfDc26a25b928
export const COLLECTOR = '0xBe85413851D195fC6341619cD68BfDc26a25b928';

// https://ftmscan.com/address/0xa5ba6E5EC19a1Bf23C857991c857dB62b2Aa187B
export const DEFAULT_A_TOKEN_IMPL_REV_1 = '0xa5ba6E5EC19a1Bf23C857991c857dB62b2Aa187B';

// https://ftmscan.com/address/0x81387c40EB75acB02757C1Ae55D5936E78c9dEd3
export const DEFAULT_VARIABLE_DEBT_TOKEN_IMPL_REV_1 = '0x81387c40EB75acB02757C1Ae55D5936E78c9dEd3';

// https://ftmscan.com/address/0x770ef9f4fe897e59daCc474EF11238303F9552b6
export const POOL_ADDRESSES_PROVIDER_REGISTRY = '0x770ef9f4fe897e59daCc474EF11238303F9552b6';

// https://ftmscan.com/address/0x1408401B2A7E28cB747b3e258D0831Fc926bAC51
export const REPAY_WITH_COLLATERAL_ADAPTER = '0x1408401B2A7E28cB747b3e258D0831Fc926bAC51';

// https://ftmscan.com/address/0xE387c6053CE8EC9f8C3fa5cE085Af73114a695d3
export const SWAP_COLLATERAL_ADAPTER = '0xE387c6053CE8EC9f8C3fa5cE085Af73114a695d3';

// https://ftmscan.com/address/0x67Da261c14fd94cE7fDd77a0A8476E5b244089A9
export const UI_INCENTIVE_DATA_PROVIDER = '0x67Da261c14fd94cE7fDd77a0A8476E5b244089A9';

// https://ftmscan.com/address/0xddf65434502E459C22263BE2ed7cF0f1FaFD44c0
export const UI_POOL_DATA_PROVIDER = '0xddf65434502E459C22263BE2ed7cF0f1FaFD44c0';

// https://ftmscan.com/address/0xBc790382B3686abffE4be14A030A96aC6154023a
export const WALLET_BALANCE_PROVIDER = '0xBc790382B3686abffE4be14A030A96aC6154023a';

// https://ftmscan.com/address/0x1DcDA4de2Bf6c7AD9a34788D22aE6b7d55016e1f
export const WETH_GATEWAY = '0x1DcDA4de2Bf6c7AD9a34788D22aE6b7d55016e1f';

export const CHAIN_ID = 250;
export const ASSETS = {
  DAI: {
    decimals: 18,
    id: 0,
    UNDERLYING: '0x8D11eC38a3EB5E956B052f67Da8Bdc9bef8Abf3E',
    A_TOKEN: '0x82E64f49Ed5EC1bC6e43DAD4FC8Af9bb3A2312EE',
    V_TOKEN: '0x8619d80FB0141ba7F184CbF22fd724116D9f7ffC',
    INTEREST_RATE_STRATEGY: '0xA9F3C3caE095527061e6d270DBE163693e6fda9D',
    ORACLE: '0x91d5DEFAFfE2854C7D02F50c80FA1fdc8A721e52',
  },
  LINK: {
    decimals: 18,
    id: 1,
    UNDERLYING: '0xb3654dc3D10Ea7645f8319668E8F54d2574FBdC8',
    A_TOKEN: '0x191c10Aa4AF7C30e871E70C95dB0E4eb77237530',
    V_TOKEN: '0x953A573793604aF8d41F306FEb8274190dB4aE0e',
    INTEREST_RATE_STRATEGY: '0x4aa694e6c06D6162d95BE98a2Df6a521d5A7b521',
    ORACLE: '0x221C773d8647BC3034e91a0c47062e26D20d97B4',
  },
  USDC: {
    decimals: 6,
    id: 2,
    UNDERLYING: '0x04068DA6C83AFCFA0e13ba15A6696662335D5B75',
    A_TOKEN: '0x625E7708f30cA75bfd92586e17077590C60eb4cD',
    V_TOKEN: '0xFCCf3cAbbe80101232d343252614b6A3eE81C989',
    INTEREST_RATE_STRATEGY: '0xf4a0039F2d4a2EaD5216AbB6Ae4C4C3AA2dB9b82',
    ORACLE: '0x2553f4eeb82d5A26427b8d1106C51499CBa5D99c',
  },
  BTC: {
    decimals: 8,
    id: 3,
    UNDERLYING: '0x321162Cd933E2Be498Cd2267a90534A804051b11',
    A_TOKEN: '0x078f358208685046a11C85e8ad32895DED33A249',
    V_TOKEN: '0x92b42c66840C7AD907b4BF74879FF3eF7c529473',
    INTEREST_RATE_STRATEGY: '0x4aa694e6c06D6162d95BE98a2Df6a521d5A7b521',
    ORACLE: '0x8e94C22142F4A64b99022ccDd994f4e9EC86E4B4',
  },
  ETH: {
    decimals: 18,
    id: 4,
    UNDERLYING: '0x74b23882a30290451A17c44f4F05243b6b58C76d',
    A_TOKEN: '0xe50fA9b3c56FfB159cB0FCA61F5c9D750e8128c8',
    V_TOKEN: '0x0c84331e39d6658Cd6e6b9ba04736cC4c4734351',
    INTEREST_RATE_STRATEGY: '0x4aa694e6c06D6162d95BE98a2Df6a521d5A7b521',
    ORACLE: '0x11DdD3d147E5b83D01cee7070027092397d63658',
  },
  fUSDT: {
    decimals: 6,
    id: 5,
    UNDERLYING: '0x049d68029688eAbF473097a2fC38ef61633A3C7A',
    A_TOKEN: '0x6ab707Aca953eDAeFBc4fD23bA73294241490620',
    V_TOKEN: '0xfb00AC187a8Eb5AFAE4eACE434F493Eb62672df7',
    INTEREST_RATE_STRATEGY: '0xf4a0039F2d4a2EaD5216AbB6Ae4C4C3AA2dB9b82',
    ORACLE: '0xF64b636c5dFe1d3555A847341cDC449f612307d0',
  },
  AAVE: {
    decimals: 18,
    id: 6,
    UNDERLYING: '0x6a07A792ab2965C72a5B8088d3a069A7aC3a993B',
    A_TOKEN: '0xf329e36C7bF6E5E86ce2150875a84Ce77f477375',
    V_TOKEN: '0xE80761Ea617F66F96274eA5e8c37f03960ecC679',
    INTEREST_RATE_STRATEGY: '0x4aa694e6c06D6162d95BE98a2Df6a521d5A7b521',
    ORACLE: '0xE6ecF7d2361B6459cBb3b4fb065E0eF4B175Fe74',
  },
  WFTM: {
    decimals: 18,
    id: 7,
    UNDERLYING: '0x21be370D5312f44cB42ce377BC9b8a0cEF1A4C83',
    A_TOKEN: '0x6d80113e533a2C0fe82EaBD35f1875DcEA89Ea97',
    V_TOKEN: '0x4a1c3aD6Ed28a636ee1751C69071f6be75DEb8B8',
    INTEREST_RATE_STRATEGY: '0x4aa694e6c06D6162d95BE98a2Df6a521d5A7b521',
    ORACLE: '0xf4766552D15AE4d256Ad41B6cf2933482B0680dc',
  },
  CRV: {
    decimals: 18,
    id: 8,
    UNDERLYING: '0x1E4F97b9f9F913c46F1632781732927B9019C68b',
    A_TOKEN: '0x513c7E3a9c69cA3e22550eF58AC1C0088e918FFf',
    V_TOKEN: '0x77CA01483f379E58174739308945f044e1a764dc',
    INTEREST_RATE_STRATEGY: '0x4aa694e6c06D6162d95BE98a2Df6a521d5A7b521',
    ORACLE: '0xa141D7E3B44594cc65142AE5F2C7844Abea66D2B',
  },
  SUSHI: {
    decimals: 18,
    id: 9,
    UNDERLYING: '0xae75A438b2E0cB8Bb01Ec1E1e376De11D44477CC',
    A_TOKEN: '0xc45A479877e1e9Dfe9FcD4056c699575a1045dAA',
    V_TOKEN: '0x34e2eD44EF7466D5f9E0b782B5c08b57475e7907',
    INTEREST_RATE_STRATEGY: '0x4aa694e6c06D6162d95BE98a2Df6a521d5A7b521',
    ORACLE: '0xCcc059a1a17577676c8673952Dc02070D29e5a66',
  },
} as const;
