// SPDX-License-Identifier: MIT
pragma solidity ^0.8.0;

library Payloads {
  address internal constant POLYGON = address(0x2Efe215aE82339fa059bb9d611E4cC858cfe9Df6);
  address internal constant GNOSIS = address(0xD410270dadBA6CAB0b3523136b79ab3a19CCecc8);
  address internal constant OPTIMISM = address(0xAdDb96Fb6A795faf042DD25BD4710267C41D1F74);
  address internal constant ARBITRUM = address(0xF5eA8A01d4e0456B605dC0f1EC4E401a8cA6397A);
  address internal constant AVALANCHE = address(0xA434D495249abE33E031Fe71a969B81f3c07950D);
  address internal constant BASE = address(0x29081f7aB5a644716EfcDC10D5c926c5fEe9F72B);
  address internal constant SCROLL = address(0x82dcCF206Ae2Ab46E2099e663F70DeE77caE7778);
  address internal constant BNB = address(0x3cd1dFB81C50A5300C60a181ED145a7286d81e0a);
  address internal constant PROTO = address(0x55c09b4Df32606667dBdF7dc846417bFb4Cec776);
  address internal constant ZKSYNC = address(0x449e788367f32a6E19C54557A4D36FA8bc4C2eB4);
  address internal constant METIS = address(0x61637B1EF7e9A102e50B661D3d7dbe19ef93347e);
  address internal constant LIDO = address(0xF4AbB0d80C1E5D4Be3dCd38a864AD5D8bFDe0ac3);
  address internal constant ETHERFI = address(0x56496FA0C8AB691dAe9632320963862108775ab2);
}
