// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// IPoolAddressesProvider https://era.zksync.network/address/0x2A3948BB219D6B2Fa83D64100006391a96bE6cb7
export const POOL_ADDRESSES_PROVIDER = '0x2A3948BB219D6B2Fa83D64100006391a96bE6cb7';

// IPool https://era.zksync.network/address/0x78e30497a3c7527d953c6B1E3541b021A98Ac43c
export const POOL = '0x78e30497a3c7527d953c6B1E3541b021A98Ac43c';

// IPoolConfigurator https://era.zksync.network/address/0x0207d31b4377C74bEC37356aaD83E3dCc979F40E
export const POOL_CONFIGURATOR = '0x0207d31b4377C74bEC37356aaD83E3dCc979F40E';

// IAaveOracle https://era.zksync.network/address/0xC7F58Fca663a8d377B6D0c9703C697f56dC40088
export const ORACLE = '0xC7F58Fca663a8d377B6D0c9703C697f56dC40088';

// https://era.zksync.network/address/0x04cE39789e11a49595cD0ECEf6f4Bd54ABF4d020
export const ACL_ADMIN = '0x04cE39789e11a49595cD0ECEf6f4Bd54ABF4d020';

// IACLManager https://era.zksync.network/address/0xc6150b63c2F02528d4A969a248710A4658ed7928
export const ACL_MANAGER = '0xc6150b63c2F02528d4A969a248710A4658ed7928';

// IPoolDataProvider https://era.zksync.network/address/0x5F2A704cE47B373c908fE8A29514249469b52b99
export const AAVE_PROTOCOL_DATA_PROVIDER = '0x5F2A704cE47B373c908fE8A29514249469b52b99';

// https://era.zksync.network/address/0x79Bef43a562047B8FDF6335b28Fa61820A442fD6
export const POOL_IMPL = '0x79Bef43a562047B8FDF6335b28Fa61820A442fD6';

// https://era.zksync.network/address/0xBc4c49630350F67D7Ec88785E5DF9A57c78a1b7d
export const POOL_CONFIGURATOR_IMPL = '0xBc4c49630350F67D7Ec88785E5DF9A57c78a1b7d';

// https://era.zksync.network/address/0x37c972C9dDfC2138EBe33eC19dba063AB9f8966e
export const DEFAULT_INCENTIVES_CONTROLLER = '0x37c972C9dDfC2138EBe33eC19dba063AB9f8966e';

// https://era.zksync.network/address/0x92AA83Ce0CC590E6B0627a9E22e84Ef43F389D1f
export const EMISSION_MANAGER = '0x92AA83Ce0CC590E6B0627a9E22e84Ef43F389D1f';

// ICollector https://era.zksync.network/address/0xd69Cbda644c6be817AaFb5Fd9174f50C33803B6b
export const COLLECTOR = '0xd69Cbda644c6be817AaFb5Fd9174f50C33803B6b';

// https://era.zksync.network/address/0x34be365Fd01ac224F21490aaC6dFd65D25434bbB
export const DEFAULT_A_TOKEN_IMPL_REV_1 = '0x34be365Fd01ac224F21490aaC6dFd65D25434bbB';

// https://era.zksync.network/address/0x52E97425D1Fa6885fAaC9260B711fA5047A88d06
export const DEFAULT_VARIABLE_DEBT_TOKEN_IMPL_REV_1 = '0x52E97425D1Fa6885fAaC9260B711fA5047A88d06';

// https://era.zksync.network/address/0x54965A9c830DCEEa6BeEa77642C6A78C3df1C957
export const CONFIG_ENGINE = '0x54965A9c830DCEEa6BeEa77642C6A78C3df1C957';

// https://era.zksync.network/address/0x0753E3637ddC6efc40759D9c347251046644F25F
export const POOL_ADDRESSES_PROVIDER_REGISTRY = '0x0753E3637ddC6efc40759D9c347251046644F25F';

// https://era.zksync.network/address/0x430Ef10d29237a0f061f9F7753fCe1cd1F5cF0e1
export const UI_INCENTIVE_DATA_PROVIDER = '0x430Ef10d29237a0f061f9F7753fCe1cd1F5cF0e1';

// https://era.zksync.network/address/0x6fCDa2646d6E4a42b1663d219811fC96AE3A0ec8
export const UI_POOL_DATA_PROVIDER = '0x6fCDa2646d6E4a42b1663d219811fC96AE3A0ec8';

// https://era.zksync.network/address/0xcb8Dc3C135e59B1252F057da44A8f43EE6B0dAB0
export const WALLET_BALANCE_PROVIDER = '0xcb8Dc3C135e59B1252F057da44A8f43EE6B0dAB0';

// https://era.zksync.network/address/0xD5f6c8D402E0a0222f7FA132F9e80fDCC074df5C
export const WETH_GATEWAY = '0xD5f6c8D402E0a0222f7FA132F9e80fDCC074df5C';

// https://era.zksync.network/address/0x1Bc8dbF1f5aF8094Aa166098131116CaAd6B22F9
export const STATIC_A_TOKEN_FACTORY = '0x1Bc8dbF1f5aF8094Aa166098131116CaAd6B22F9';

// https://era.zksync.network/address/0x05c77Cf62346329a157d7A6F874464D049CECb26
export const RISK_STEWARD = '0x05c77Cf62346329a157d7A6F874464D049CECb26';

export const CHAIN_ID = 324;
export const ASSETS = {
  USDC: {
    decimals: 6,
    id: 0,
    UNDERLYING: '0x1d17CBcF0D6D143135aE902365D2E5e2A16538D4',
    A_TOKEN: '0xE977F9B2a5ccf0457870a67231F23BE4DaecfbDb',
    V_TOKEN: '0x0049250D15A8550c5a14Baa5AF5B662a93a525B9',
    INTEREST_RATE_STRATEGY: '0x57815Ab06D846d7dECd326Ee541CD06144FED237',
    ORACLE: '0x22A46593A7f93Aaec788bE3e27C1838E15781222',
  },
  USDT: {
    decimals: 6,
    id: 1,
    UNDERLYING: '0x493257fD37EDB34451f62EDf8D2a0C418852bA4C',
    A_TOKEN: '0xC48574bc5358c967d9447e7Df70230Fdb469e4E7',
    V_TOKEN: '0x8992DB58077fe8C7B80c1B3a738eAe8A7BdDbA34',
    INTEREST_RATE_STRATEGY: '0x57815Ab06D846d7dECd326Ee541CD06144FED237',
    ORACLE: '0xE8D6d2dffCFfFc6b1f3606b7552e80319D01A8E9',
  },
  WETH: {
    decimals: 18,
    id: 2,
    UNDERLYING: '0x5AEa5775959fBC2557Cc8789bC1bf90A239D9a91',
    A_TOKEN: '0xb7b93bCf82519bB757Fd18b23A389245Dbd8ca64',
    V_TOKEN: '0x98dC737eA0E9bCb254c3F98510a71c5E11F74238',
    INTEREST_RATE_STRATEGY: '0x57815Ab06D846d7dECd326Ee541CD06144FED237',
    ORACLE: '0x6D41d1dc818112880b40e26BD6FD347E41008eDA',
  },
  wstETH: {
    decimals: 18,
    id: 3,
    UNDERLYING: '0x703b52F2b28fEbcB60E1372858AF5b18849FE867',
    A_TOKEN: '0xd4e607633F3d984633E946aEA4eb71f92564c1c9',
    V_TOKEN: '0x6aD279F6523f6421fD5B0324a97D8F62eeCD80c8',
    INTEREST_RATE_STRATEGY: '0x57815Ab06D846d7dECd326Ee541CD06144FED237',
    ORACLE: '0xdea7DE07B8275564Af6135F7E9340411246EB7A2',
  },
  ZK: {
    decimals: 18,
    id: 4,
    UNDERLYING: '0x5A7d6b2F92C77FAD6CCaBd7EE0624E64907Eaf3E',
    A_TOKEN: '0xd6cD2c0fC55936498726CacC497832052A9B2D1B',
    V_TOKEN: '0x6450fd7F877B5bB726F7Bc6Bf0e6ffAbd48d72ad',
    INTEREST_RATE_STRATEGY: '0x57815Ab06D846d7dECd326Ee541CD06144FED237',
    ORACLE: '0xD1ce60dc8AE060DDD17cA8716C96f193bC88DD13',
  },
} as const;
export const E_MODES = {
  '1': {
    label: 'ETH correlated',
    collateralBitmap: '12',
    collateralAssets: [
      '0x5AEa5775959fBC2557Cc8789bC1bf90A239D9a91',
      '0x703b52F2b28fEbcB60E1372858AF5b18849FE867',
    ],
    borrowableBitmap: '12',
    borrowableAssets: [
      '0x5AEa5775959fBC2557Cc8789bC1bf90A239D9a91',
      '0x703b52F2b28fEbcB60E1372858AF5b18849FE867',
    ],
    ltv: 9000,
    liquidationThreshold: 9300,
    liquidationBonus: 10100,
  },
} as const;
export const EXTERNAL_LIBRARIES = {} as const;
