// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://sepolia.basescan.org/address/0xeF4d1F3F0dCe46C1Ad684F23Ea3aA542592A8cFe
export const TRANSPARENT_PROXY_FACTORY = '0xeF4d1F3F0dCe46C1Ad684F23Ea3aA542592A8cFe';

// https://sepolia.basescan.org/address/0xbeCE3Cb857644b44Bb44084f9AfE784473ADb17B
export const PROXY_ADMIN = '0xbeCE3Cb857644b44Bb44084f9AfE784473ADb17B';

// https://sepolia.basescan.org/address/0x7CFa3f3d1cded0Da930881c609D4Dbf0012c14Bb
export const GHO_TOKEN = '0x7CFa3f3d1cded0Da930881c609D4Dbf0012c14Bb';

export const CHAIN_ID = 84532;
