// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscScroll {
  // https://scrollscan.com/address/0xFa2eeb2d0054C3Db2A606E2cd9EE111b62707D1e
  address internal constant TRANSPARENT_PROXY_FACTORY = 0xFa2eeb2d0054C3Db2A606E2cd9EE111b62707D1e;

  // https://scrollscan.com/address/0x782559e349b084bB7C07c08404aE6E3436cDAE2E
  address internal constant PROXY_ADMIN = 0x782559e349b084bB7C07c08404aE6E3436cDAE2E;

  // https://scrollscan.com/address/0xC6f44D0daC966658Db36742f5153bDa0EBbb45ab
  address internal constant CREATE_3_FACTORY = 0xC6f44D0daC966658Db36742f5153bDa0EBbb45ab;

  // https://scrollscan.com/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
  address internal constant PROTOCOL_GUARDIAN = 0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6;

  // https://scrollscan.com/address/0xE61Da4C909F7d86797a0D06Db63c34f76c9bCBDC
  address internal constant wstETH_stETH_AGGREGATOR = 0xE61Da4C909F7d86797a0D06Db63c34f76c9bCBDC;
}
