// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://scrollscan.com/address/0xFa2eeb2d0054C3Db2A606E2cd9EE111b62707D1e
export const TRANSPARENT_PROXY_FACTORY = '0xFa2eeb2d0054C3Db2A606E2cd9EE111b62707D1e';

// https://scrollscan.com/address/0x782559e349b084bB7C07c08404aE6E3436cDAE2E
export const PROXY_ADMIN = '0x782559e349b084bB7C07c08404aE6E3436cDAE2E';

// https://scrollscan.com/address/0xC6f44D0daC966658Db36742f5153bDa0EBbb45ab
export const CREATE_3_FACTORY = '0xC6f44D0daC966658Db36742f5153bDa0EBbb45ab';

// https://scrollscan.com/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
export const PROTOCOL_GUARDIAN = '0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6';

// https://scrollscan.com/address/0xE61Da4C909F7d86797a0D06Db63c34f76c9bCBDC
export const wstETH_stETH_AGGREGATOR = '0xE61Da4C909F7d86797a0D06Db63c34f76c9bCBDC';

export const CHAIN_ID = 534352;
