// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscZkSync {
  // https://era.zksync.network/address/0x903A3228c4C58e94787CB33EE83e087bCFcF0a91
  address internal constant TRANSPARENT_PROXY_FACTORY = 0x903A3228c4C58e94787CB33EE83e087bCFcF0a91;

  // https://era.zksync.network/address/0x158d6c497317367CEa3CBAb0BD84E6de236F060D
  address internal constant PROXY_ADMIN = 0x158d6c497317367CEa3CBAb0BD84E6de236F060D;

  // https://era.zksync.network/address/0xba845c27903F7dDB5c676e5b74728C871057E000
  address internal constant PROTOCOL_GUARDIAN = 0xba845c27903F7dDB5c676e5b74728C871057E000;
}
