// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// IPoolAddressesProvider https://snowtrace.io/address/0xa97684ead0e402dC232d5A977953DF7ECBaB3CDb
export const POOL_ADDRESSES_PROVIDER = '0xa97684ead0e402dC232d5A977953DF7ECBaB3CDb';

// IPool https://snowtrace.io/address/0x794a61358D6845594F94dc1DB02A252b5b4814aD
export const POOL = '0x794a61358D6845594F94dc1DB02A252b5b4814aD';

// IPoolConfigurator https://snowtrace.io/address/0x8145eddDf43f50276641b55bd3AD95944510021E
export const POOL_CONFIGURATOR = '0x8145eddDf43f50276641b55bd3AD95944510021E';

// IAaveOracle https://snowtrace.io/address/0xEBd36016B3eD09D4693Ed4251c67Bd858c3c7C9C
export const ORACLE = '0xEBd36016B3eD09D4693Ed4251c67Bd858c3c7C9C';

// https://snowtrace.io/address/0x3C06dce358add17aAf230f2234bCCC4afd50d090
export const ACL_ADMIN = '0x3C06dce358add17aAf230f2234bCCC4afd50d090';

// IACLManager https://snowtrace.io/address/0xa72636CbcAa8F5FF95B2cc47F3CDEe83F3294a0B
export const ACL_MANAGER = '0xa72636CbcAa8F5FF95B2cc47F3CDEe83F3294a0B';

// IPoolDataProvider https://snowtrace.io/address/0x7F23D86Ee20D869112572136221e173428DD740B
export const AAVE_PROTOCOL_DATA_PROVIDER = '0x7F23D86Ee20D869112572136221e173428DD740B';

// https://snowtrace.io/address/0x5DFb8c777C19d3cEdcDc7398d2EeF1FB0b9b05c9
export const POOL_IMPL = '0x5DFb8c777C19d3cEdcDc7398d2EeF1FB0b9b05c9';

// https://snowtrace.io/address/0x4816b2C2895f97fB918f1aE7Da403750a0eE372e
export const POOL_CONFIGURATOR_IMPL = '0x4816b2C2895f97fB918f1aE7Da403750a0eE372e';

// https://snowtrace.io/address/0x929EC64c34a17401F460460D4B9390518E5B473e
export const DEFAULT_INCENTIVES_CONTROLLER = '0x929EC64c34a17401F460460D4B9390518E5B473e';

// https://snowtrace.io/address/0x048f2228D7Bf6776f99aB50cB1b1eaB4D1d4cA73
export const EMISSION_MANAGER = '0x048f2228D7Bf6776f99aB50cB1b1eaB4D1d4cA73';

// ICollector https://snowtrace.io/address/0x5ba7fd868c40c16f7aDfAe6CF87121E13FC2F7a0
export const COLLECTOR = '0x5ba7fd868c40c16f7aDfAe6CF87121E13FC2F7a0';

// https://snowtrace.io/address/0x1E81af09001aD208BDa68FF022544dB2102A752d
export const DEFAULT_A_TOKEN_IMPL_REV_2 = '0x1E81af09001aD208BDa68FF022544dB2102A752d';

// https://snowtrace.io/address/0xa0d9C1E9E48Ca30c8d8C3B5D69FF5dc1f6DFfC24
export const DEFAULT_VARIABLE_DEBT_TOKEN_IMPL_REV_2 = '0xa0d9C1E9E48Ca30c8d8C3B5D69FF5dc1f6DFfC24';

// https://snowtrace.io/address/0xD2C92b5A793e196aB11dBefBe3Af6BddeD6c3DD5
export const CAPS_PLUS_RISK_STEWARD = '0xD2C92b5A793e196aB11dBefBe3Af6BddeD6c3DD5';

// https://snowtrace.io/address/0xbf03aB677DEdA36E19D294d1735b93Dd9d1E0c05
export const RISK_STEWARD = '0xbf03aB677DEdA36E19D294d1735b93Dd9d1E0c05';

// https://snowtrace.io/address/0x6d4F341d8Bb3Dc5ABe822Aa940F1884508C13f99
export const FREEZING_STEWARD = '0x6d4F341d8Bb3Dc5ABe822Aa940F1884508C13f99';

// https://snowtrace.io/address/0xE28E2c8d240dd5eBd0adcab86fbD79df7a052034
export const DEBT_SWAP_ADAPTER = '0xE28E2c8d240dd5eBd0adcab86fbD79df7a052034';

// https://snowtrace.io/address/0x9aaB9F0b6E19907e346420Edc0d3029Edb5e8616
export const CONFIG_ENGINE = '0x9aaB9F0b6E19907e346420Edc0d3029Edb5e8616';

// https://snowtrace.io/address/0x770ef9f4fe897e59daCc474EF11238303F9552b6
export const POOL_ADDRESSES_PROVIDER_REGISTRY = '0x770ef9f4fe897e59daCc474EF11238303F9552b6';

// https://snowtrace.io/address/0xab22988D93d5F942fC6B6c6Ea285744809D1d9Cc
export const PROOF_OF_RESERVE = '0xab22988D93d5F942fC6B6c6Ea285744809D1d9Cc';

// https://snowtrace.io/address/0x80f2c02224a2E548FC67c0bF705eBFA825dd5439
export const PROOF_OF_RESERVE_AGGREGATOR = '0x80f2c02224a2E548FC67c0bF705eBFA825dd5439';

// https://snowtrace.io/address/0x5d4D4007A4c6336550DdAa2a7c0d5e7972eebd16
export const REPAY_WITH_COLLATERAL_ADAPTER = '0x5d4D4007A4c6336550DdAa2a7c0d5e7972eebd16';

// https://snowtrace.io/address/0x691C316b2Eec7e64d17e7E3E01f3dB44c9CcEf19
export const STATIC_A_TOKEN_FACTORY = '0x691C316b2Eec7e64d17e7E3E01f3dB44c9CcEf19';

// https://snowtrace.io/address/0x2Cf641F7C0eac2788A7924B82d6Ca8EB7bAa4E3A
export const SWAP_COLLATERAL_ADAPTER = '0x2Cf641F7C0eac2788A7924B82d6Ca8EB7bAa4E3A';

// https://snowtrace.io/address/0x99732D5dA21f44f9e45e36eF9da4B1df2Eb0b28E
export const UI_INCENTIVE_DATA_PROVIDER = '0x99732D5dA21f44f9e45e36eF9da4B1df2Eb0b28E';

// https://snowtrace.io/address/0x50B4a66bF4D41e6252540eA7427D7A933Bc3c088
export const UI_POOL_DATA_PROVIDER = '0x50B4a66bF4D41e6252540eA7427D7A933Bc3c088';

// https://snowtrace.io/address/0xBc790382B3686abffE4be14A030A96aC6154023a
export const WALLET_BALANCE_PROVIDER = '0xBc790382B3686abffE4be14A030A96aC6154023a';

// https://snowtrace.io/address/0xCf3045a03F83ADfBCbA1f19Cb2cF4E19075F8668
export const WETH_GATEWAY = '0xCf3045a03F83ADfBCbA1f19Cb2cF4E19075F8668';

// https://snowtrace.io/address/0x78F8Bd884C3D738B74B420540659c82f392820e0
export const WITHDRAW_SWAP_ADAPTER = '0x78F8Bd884C3D738B74B420540659c82f392820e0';

export const CHAIN_ID = 43114;
export const ASSETS = {
  DAIe: {
    decimals: 18,
    id: 0,
    UNDERLYING: '0xd586E7F844cEa2F87f50152665BCbc2C279D8d70',
    A_TOKEN: '0x82E64f49Ed5EC1bC6e43DAD4FC8Af9bb3A2312EE',
    V_TOKEN: '0x8619d80FB0141ba7F184CbF22fd724116D9f7ffC',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0xf82da795727633aFA9BB0f1B08A87c0F6A38723f',
    STATIC_A_TOKEN: '0x02F3f6c8A432C1e49f3359d7d36887C25d8A5888',
  },
  LINKe: {
    decimals: 18,
    id: 1,
    UNDERLYING: '0x5947BB275c521040051D82396192181b413227A3',
    A_TOKEN: '0x191c10Aa4AF7C30e871E70C95dB0E4eb77237530',
    V_TOKEN: '0x953A573793604aF8d41F306FEb8274190dB4aE0e',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x49ccd9ca821EfEab2b98c60dC60F518E765EDe9a',
    STATIC_A_TOKEN: '0x8B773Ab77Dff01985D438961dBCE58382a70cA52',
  },
  USDC: {
    decimals: 6,
    id: 2,
    UNDERLYING: '0xB97EF9Ef8734C71904D8002F8b6Bc66Dd9c48a6E',
    A_TOKEN: '0x625E7708f30cA75bfd92586e17077590C60eb4cD',
    V_TOKEN: '0xFCCf3cAbbe80101232d343252614b6A3eE81C989',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0xD8277249e871BE9A402fa286C2C5ec16046dC512',
    STATIC_A_TOKEN: '0xC509aB7bB4eDbF193b82264D499a7Fc526Cd01F4',
  },
  WBTCe: {
    decimals: 8,
    id: 3,
    UNDERLYING: '0x50b7545627a5162F82A992c33b87aDc75187B218',
    A_TOKEN: '0x078f358208685046a11C85e8ad32895DED33A249',
    V_TOKEN: '0x92b42c66840C7AD907b4BF74879FF3eF7c529473',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x2779D32d5166BAaa2B2b658333bA7e6Ec0C65743',
    STATIC_A_TOKEN: '0xE3C0f42EAF1a4BFe37CbA105e5463564BA7730aE',
  },
  WETHe: {
    decimals: 18,
    id: 4,
    UNDERLYING: '0x49D5c2BdFfac6CE2BFdB6640F4F80f226bc10bAB',
    A_TOKEN: '0xe50fA9b3c56FfB159cB0FCA61F5c9D750e8128c8',
    V_TOKEN: '0x0c84331e39d6658Cd6e6b9ba04736cC4c4734351',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x976B3D034E162d8bD72D6b9C989d545b839003b0',
    STATIC_A_TOKEN: '0xf8E24175D01653fd6AA203C2C17B1e4Dd1CA2731',
  },
  USDt: {
    decimals: 6,
    id: 5,
    UNDERLYING: '0x9702230A8Ea53601f5cD2dc00fDBc13d4dF4A8c7',
    A_TOKEN: '0x6ab707Aca953eDAeFBc4fD23bA73294241490620',
    V_TOKEN: '0xfb00AC187a8Eb5AFAE4eACE434F493Eb62672df7',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x39185f2236A6022b682e8BB93C040d125DA093CF',
    STATIC_A_TOKEN: '0x5525Ee69BC1e354B356864187De486fab5AD67d7',
  },
  AAVEe: {
    decimals: 18,
    id: 6,
    UNDERLYING: '0x63a72806098Bd3D9520cC43356dD78afe5D386D9',
    A_TOKEN: '0xf329e36C7bF6E5E86ce2150875a84Ce77f477375',
    V_TOKEN: '0xE80761Ea617F66F96274eA5e8c37f03960ecC679',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x3CA13391E9fb38a75330fb28f8cc2eB3D9ceceED',
    STATIC_A_TOKEN: '0xac0746AfD13DEbe2a43a6c8745Fb83Fd2A2909cA',
  },
  WAVAX: {
    decimals: 18,
    id: 7,
    UNDERLYING: '0xB31f66AA3C1e785363F0875A1B74E27b85FD66c7',
    A_TOKEN: '0x6d80113e533a2C0fe82EaBD35f1875DcEA89Ea97',
    V_TOKEN: '0x4a1c3aD6Ed28a636ee1751C69071f6be75DEb8B8',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x0A77230d17318075983913bC2145DB16C7366156',
    STATIC_A_TOKEN: '0x6A02C7a974F1F13A67980C80F774eC1d2eD8f98d',
  },
  sAVAX: {
    decimals: 18,
    id: 8,
    UNDERLYING: '0x2b2C81e08f1Af8835a78Bb2A90AE924ACE0eA4bE',
    A_TOKEN: '0x513c7E3a9c69cA3e22550eF58AC1C0088e918FFf',
    V_TOKEN: '0x77CA01483f379E58174739308945f044e1a764dc',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0xB2B332f27e4B7305649a228C31Ed9858c5a6bAD9',
    STATIC_A_TOKEN: '0x4F059cA8a2a5BF8895Ee731f2E901cCB769FB95f',
  },
  FRAX: {
    decimals: 18,
    id: 9,
    UNDERLYING: '0xD24C2Ad096400B6FBcd2ad8B24E7acBc21A1da64',
    A_TOKEN: '0xc45A479877e1e9Dfe9FcD4056c699575a1045dAA',
    V_TOKEN: '0x34e2eD44EF7466D5f9E0b782B5c08b57475e7907',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x6208576378D06ce69A27987b7A524A9B15d499a4',
    STATIC_A_TOKEN: '0xA3c2ffE702F4cD265B2249AB5f84Fab81FFf6c73',
  },
  MAI: {
    decimals: 18,
    id: 10,
    UNDERLYING: '0x5c49b268c9841AFF1Cc3B0a418ff5c3442eE3F3b',
    A_TOKEN: '0x8Eb270e296023E9D92081fdF967dDd7878724424',
    V_TOKEN: '0xCE186F6Cccb0c955445bb9d10C59caE488Fea559',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0xCcC55Db26B78a19Dba1beE0066F9c1665575439A',
    STATIC_A_TOKEN: '0x08cC59E51BB0Bc322B4D251f7262dB864d6150ce',
  },
  BTCb: {
    decimals: 8,
    id: 11,
    UNDERLYING: '0x152b9d0FdC40C096757F570A51E494bd4b943E50',
    A_TOKEN: '0x8ffDf2DE812095b1D19CB146E4c004587C0A0692',
    V_TOKEN: '0xA8669021776Bc142DfcA87c21b4A52595bCbB40a',
    INTEREST_RATE_STRATEGY: '0xCe1C5509f2f4d755aA64B8D135B15ec6F12a93da',
    ORACLE: '0x2779D32d5166BAaa2B2b658333bA7e6Ec0C65743',
    STATIC_A_TOKEN: '0x34d768cc830c32DcD743321c09A2A702651bF9a2',
  },
} as const;
export const E_MODES = {
  '1': {
    label: 'Stablecoins',
    collateralBitmap: '1573',
    collateralAssets: [
      '0xd586E7F844cEa2F87f50152665BCbc2C279D8d70',
      '0xB97EF9Ef8734C71904D8002F8b6Bc66Dd9c48a6E',
      '0x9702230A8Ea53601f5cD2dc00fDBc13d4dF4A8c7',
      '0xD24C2Ad096400B6FBcd2ad8B24E7acBc21A1da64',
      '0x5c49b268c9841AFF1Cc3B0a418ff5c3442eE3F3b',
    ],
    borrowableBitmap: '1573',
    borrowableAssets: [
      '0xd586E7F844cEa2F87f50152665BCbc2C279D8d70',
      '0xB97EF9Ef8734C71904D8002F8b6Bc66Dd9c48a6E',
      '0x9702230A8Ea53601f5cD2dc00fDBc13d4dF4A8c7',
      '0xD24C2Ad096400B6FBcd2ad8B24E7acBc21A1da64',
      '0x5c49b268c9841AFF1Cc3B0a418ff5c3442eE3F3b',
    ],
    ltv: 9300,
    liquidationThreshold: 9500,
    liquidationBonus: 10100,
  },
  '2': {
    label: 'AVAX correlated',
    collateralBitmap: '384',
    collateralAssets: [
      '0xB31f66AA3C1e785363F0875A1B74E27b85FD66c7',
      '0x2b2C81e08f1Af8835a78Bb2A90AE924ACE0eA4bE',
    ],
    borrowableBitmap: '384',
    borrowableAssets: [
      '0xB31f66AA3C1e785363F0875A1B74E27b85FD66c7',
      '0x2b2C81e08f1Af8835a78Bb2A90AE924ACE0eA4bE',
    ],
    ltv: 9300,
    liquidationThreshold: 9500,
    liquidationBonus: 10100,
  },
} as const;
export const EXTERNAL_LIBRARIES = {} as const;
