// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscBNB {
  // https://bscscan.com/address/0x47aAdaAE1F05C978E6aBb7568d11B7F6e0FC4d6A
  address internal constant TRANSPARENT_PROXY_FACTORY = 0x47aAdaAE1F05C978E6aBb7568d11B7F6e0FC4d6A;

  // https://bscscan.com/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
  address internal constant PROTOCOL_GUARDIAN = 0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6;

  // https://bscscan.com/address/0xAe940e61E9863178b71500c9B5faE2a04Da361a1
  address internal constant PARASWAP_FEE_CLAIMER = 0xAe940e61E9863178b71500c9B5faE2a04Da361a1;

  // https://bscscan.com/address/0x39EBFfc7679c62Dfcc4A3E2c09Bcb0be255Ae63c
  address internal constant PROXY_ADMIN = 0x39EBFfc7679c62Dfcc4A3E2c09Bcb0be255Ae63c;

  // https://bscscan.com/address/0x3b56998Ec06477704622ca8e2eA1b4db134cec32
  address internal constant CREATE_3_FACTORY = 0x3b56998Ec06477704622ca8e2eA1b4db134cec32;

  // https://bscscan.com/address/0x51Bd3d6011Dd0BD88Ee1bEA1a67be799A6A09D79
  address internal constant AAVE_CL_ROBOT_OPERATOR = 0x51Bd3d6011Dd0BD88Ee1bEA1a67be799A6A09D79;
}
