// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscMumbai {
  // https://mumbai.polygonscan.com/address/0x49A726CC7B438dBc4fB89a9548B5E8691e1C35A6
  address internal constant TRANSPARENT_PROXY_FACTORY = 0x49A726CC7B438dBc4fB89a9548B5E8691e1C35A6;

  // https://mumbai.polygonscan.com/address/0xaebfFE29D8E823e8E43695648F418fa8c30AF879
  address internal constant PROXY_ADMIN = 0xaebfFE29D8E823e8E43695648F418fa8c30AF879;
}
