// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscBase {
  // https://basescan.org/address/0xAe940e61E9863178b71500c9B5faE2a04Da361a1
  address internal constant PARASWAP_FEE_CLAIMER = 0xAe940e61E9863178b71500c9B5faE2a04Da361a1;

  // https://basescan.org/address/0x05225Cd708bCa9253789C1374e4337a019e99D56
  address internal constant TRANSPARENT_PROXY_FACTORY = 0x05225Cd708bCa9253789C1374e4337a019e99D56;

  // https://basescan.org/address/0xc85b1E333aecc99340b2320493Fe2d22b8734795
  address internal constant PROXY_ADMIN = 0xc85b1E333aecc99340b2320493Fe2d22b8734795;

  // https://basescan.org/address/0x3b56998Ec06477704622ca8e2eA1b4db134cec32
  address internal constant CREATE_3_FACTORY = 0x3b56998Ec06477704622ca8e2eA1b4db134cec32;

  // https://basescan.org/address/0x88db99eeBb390a2a4DcAC2E1DDb09c07E911C5C3
  address internal constant AAVE_CL_ROBOT_OPERATOR = 0x88db99eeBb390a2a4DcAC2E1DDb09c07E911C5C3;

  // https://basescan.org/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
  address internal constant PROTOCOL_GUARDIAN = 0x56C1a4b54921DEA9A344967a8693C7E661D72968;

  // https://basescan.org/address/0xB88BAc61a4Ca37C43a3725912B1f472c9A5bc061
  address internal constant wstETH_stETH_AGGREGATOR = 0xB88BAc61a4Ca37C43a3725912B1f472c9A5bc061;

  // https://basescan.org/address/0x868a501e68F3D1E89CfC0D22F6b22E8dabce5F04
  address internal constant cbETH_ETH_AGGREGATOR = 0x868a501e68F3D1E89CfC0D22F6b22E8dabce5F04;

  // https://basescan.org/address/0xA9F30e6ED4098e9439B2ac8aEA2d3fc26BcEbb45
  address internal constant LEGACY_BRIDGE_EXECUTOR = 0xA9F30e6ED4098e9439B2ac8aEA2d3fc26BcEbb45;
}
