// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

import {IAaveEcosystemReserveController} from './common/IAaveEcosystemReserveController.sol';
import {IStreamable} from './common/IStreamable.sol';
library MiscEthereum {
  // https://etherscan.io/address/0x3d569673dAa0575c936c7c67c4E6AedA69CC630C
  IAaveEcosystemReserveController internal constant AAVE_ECOSYSTEM_RESERVE_CONTROLLER =
    IAaveEcosystemReserveController(0x3d569673dAa0575c936c7c67c4E6AedA69CC630C);

  // https://etherscan.io/address/0x25F2226B597E8F9514B3F68F00f494cF4f286491
  address internal constant ECOSYSTEM_RESERVE = 0x25F2226B597E8F9514B3F68F00f494cF4f286491;

  // https://etherscan.io/address/0x86C3FfeE349A7cFf7cA88C449717B1b133bfb517
  address internal constant PROXY_ADMIN_LONG = 0x86C3FfeE349A7cFf7cA88C449717B1b133bfb517;

  // https://etherscan.io/address/0x3ea64b1C0194524b48F9118462C8E9cd61a243c7
  address internal constant AAVE_SWAPPER = 0x3ea64b1C0194524b48F9118462C8E9cd61a243c7;

  // https://etherscan.io/address/0x1C2BA5b8ab8e795fF44387ba6d251fa65AD20b36
  address internal constant AAVE_POL_ETH_BRIDGE = 0x1C2BA5b8ab8e795fF44387ba6d251fa65AD20b36;

  // https://etherscan.io/address/0x9abf798f5314BFd793A9E57A654BEd35af4A1D60
  address internal constant PARASWAP_FEE_CLAIMER = 0x9abf798f5314BFd793A9E57A654BEd35af4A1D60;

  // https://etherscan.io/address/0xB4e496f70602fE2AC6Ae511D028BA4D194773B29
  address internal constant TRANSPARENT_PROXY_FACTORY = 0xB4e496f70602fE2AC6Ae511D028BA4D194773B29;

  // https://etherscan.io/address/0xD3cF979e676265e4f6379749DECe4708B9A22476
  address internal constant PROXY_ADMIN = 0xD3cF979e676265e4f6379749DECe4708B9A22476;

  // https://etherscan.io/address/0xcc3C54B95f3f1867A43009B80ed4DD930E3cE2F7
  address internal constant CREATE_3_FACTORY = 0xcc3C54B95f3f1867A43009B80ed4DD930E3cE2F7;

  // https://etherscan.io/address/0x1cDF8879eC8bE012bA959EB515b11008E0cb6323
  address internal constant AAVE_CL_ROBOT_OPERATOR = 0x1cDF8879eC8bE012bA959EB515b11008E0cb6323;

  // https://etherscan.io/address/0x2CFe3ec4d5a6811f4B8067F0DE7e47DfA938Aa30
  address internal constant PROTOCOL_GUARDIAN = 0x2CFe3ec4d5a6811f4B8067F0DE7e47DfA938Aa30;

  // https://etherscan.io/address/0xa88c6D90eAe942291325f9ae3c66f3563B93FE10
  address internal constant AAVE_MERKLE_DISTRIBUTOR = 0xa88c6D90eAe942291325f9ae3c66f3563B93FE10;

  // https://etherscan.io/address/0x40D16FC0246aD3160Ccc09B8D0D3A2cD28aE6C2f
  address internal constant GHO_TOKEN = 0x40D16FC0246aD3160Ccc09B8D0D3A2cD28aE6C2f;

  // https://etherscan.io/address/0xb639D208Bcf0589D54FaC24E655C79EC529762B8
  address internal constant GHO_FLASHMINTER_FACILITATOR =
    0xb639D208Bcf0589D54FaC24E655C79EC529762B8;

  // https://etherscan.io/address/0x5756880B6a1EAba0175227bf02a7E87c1e02B28C
  address internal constant GHO_CCIP_TOKEN_POOL = 0x5756880B6a1EAba0175227bf02a7E87c1e02B28C;

  // https://etherscan.io/address/0x167527DB01325408696326e3580cd8e55D99Dc1A
  address internal constant GSM_REGISTRY = 0x167527DB01325408696326e3580cd8e55D99Dc1A;

  // https://etherscan.io/address/0x0d8eFfC11dF3F229AA1EA0509BC9DFa632A13578
  address internal constant GSM_USDC = 0x0d8eFfC11dF3F229AA1EA0509BC9DFa632A13578;

  // https://etherscan.io/address/0x686F8D21520f4ecEc7ba577be08354F4d1EB8262
  address internal constant GSM_USDT = 0x686F8D21520f4ecEc7ba577be08354F4d1EB8262;

  // https://etherscan.io/address/0xD4478A76aCeA81D3768A0ACB6e38f25eEB6Eb1B5
  address internal constant GSM_USDC_FEE_STRATEGY = 0xD4478A76aCeA81D3768A0ACB6e38f25eEB6Eb1B5;

  // https://etherscan.io/address/0xD4478A76aCeA81D3768A0ACB6e38f25eEB6Eb1B5
  address internal constant GSM_USDT_FEE_STRATEGY = 0xD4478A76aCeA81D3768A0ACB6e38f25eEB6Eb1B5;

  // https://etherscan.io/address/0x430BEdcA5DfA6f94d1205Cb33AB4f008D0d9942a
  address internal constant GSM_USDC_PRICE_STRATEGY = 0x430BEdcA5DfA6f94d1205Cb33AB4f008D0d9942a;

  // https://etherscan.io/address/0x4c707764cbFB4FFa078e169e6b8A6AdbE7526a2c
  address internal constant GSM_USDT_PRICE_STRATEGY = 0x4c707764cbFB4FFa078e169e6b8A6AdbE7526a2c;

  // https://etherscan.io/address/0xef6beCa8D9543eC007bceA835aF768B58F730C1f
  address internal constant GSM_USDC_ORACLE_SWAP_FREEZER =
    0xef6beCa8D9543eC007bceA835aF768B58F730C1f;

  // https://etherscan.io/address/0x71381e6718b37C12155CB961Ca3D374A8BfFa0e5
  address internal constant GSM_USDT_ORACLE_SWAP_FREEZER =
    0x71381e6718b37C12155CB961Ca3D374A8BfFa0e5;

  // https://etherscan.io/address/0x197E90f9FAD81970bA7976f33CbD77088E5D7cf7
  address internal constant sDAI_POT = 0x197E90f9FAD81970bA7976f33CbD77088E5D7cf7;

  // https://etherscan.io/address/0x004626A008B1aCdC4c74ab51644093b155e59A23
  address internal constant stEUR = 0x004626A008B1aCdC4c74ab51644093b155e59A23;

  // https://etherscan.io/address/0xb4d5289C58CE36080b0748B47F859D8F50dFAACb
  address internal constant agEUR_EUR_AGGREGATOR = 0xb4d5289C58CE36080b0748B47F859D8F50dFAACb;

  // https://etherscan.io/address/0xb49f677943BC038e9857d61E7d053CaA2C1734C1
  address internal constant EUR_USD_AGGREGATOR = 0xb49f677943BC038e9857d61E7d053CaA2C1734C1;

  // https://etherscan.io/address/0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee
  address internal constant weETH_RATIO_PROVIDER = 0xCd5fE23C85820F7B72D0926FC9b05b43E359b7ee;
}
