// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://gnosisscan.io/address/0x47aAdaAE1F05C978E6aBb7568d11B7F6e0FC4d6A
export const TRANSPARENT_PROXY_FACTORY = '0x47aAdaAE1F05C978E6aBb7568d11B7F6e0FC4d6A';

// https://gnosisscan.io/address/0xe892E40C92c2E4D281Be59b2E6300F271d824E75
export const PROXY_ADMIN = '0xe892E40C92c2E4D281Be59b2E6300F271d824E75';

// https://gnosisscan.io/address/0x2cC41488f4494c5e11cB6cbA82199442B9f495B6
export const CREATE_3_FACTORY = '0x2cC41488f4494c5e11cB6cbA82199442B9f495B6';

// https://gnosisscan.io/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
export const PROTOCOL_GUARDIAN = '0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6';

// https://gnosisscan.io/address/0x0064AC007fF665CF8D0D3Af5E0AD1c26a3f853eA
export const wstETH_stETH_AGGREGATOR = '0x0064AC007fF665CF8D0D3Af5E0AD1c26a3f853eA';

export const CHAIN_ID = 100;
