// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://arbiscan.io/address/0x9abf798f5314BFd793A9E57A654BEd35af4A1D60
export const PARASWAP_FEE_CLAIMER = '0x9abf798f5314BFd793A9E57A654BEd35af4A1D60';

// https://arbiscan.io/address/0xB4e496f70602fE2AC6Ae511D028BA4D194773B29
export const TRANSPARENT_PROXY_FACTORY = '0xB4e496f70602fE2AC6Ae511D028BA4D194773B29';

// https://arbiscan.io/address/0xD3cF979e676265e4f6379749DECe4708B9A22476
export const PROXY_ADMIN = '0xD3cF979e676265e4f6379749DECe4708B9A22476';

// https://arbiscan.io/address/0x3b56998Ec06477704622ca8e2eA1b4db134cec32
export const CREATE_3_FACTORY = '0x3b56998Ec06477704622ca8e2eA1b4db134cec32';

// https://arbiscan.io/address/0xaa944aD95e51CB83C1f35FAEEDfC7d2c31B0BB4d
export const AAVE_CL_ROBOT_OPERATOR = '0xaa944aD95e51CB83C1f35FAEEDfC7d2c31B0BB4d';

// https://arbiscan.io/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
export const PROTOCOL_GUARDIAN = '0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6';

// https://arbiscan.io/address/0xB1552C5e96B312d0Bf8b554186F846C40614a540
export const wstETH_stETH_AGGREGATOR = '0xB1552C5e96B312d0Bf8b554186F846C40614a540';

// https://arbiscan.io/address/0xF3272CAfe65b190e76caAF483db13424a3e23dD2
export const rETH_ETH_AGGREGATOR = '0xF3272CAfe65b190e76caAF483db13424a3e23dD2';

// https://arbiscan.io/address/0xF168B83598516A532a85995b52504a2Fa058C068
export const GHO_CCIP_TOKEN_POOL = '0xF168B83598516A532a85995b52504a2Fa058C068';

// https://arbiscan.io/address/0x7d9103572bE58FfE99dc390E8246f02dcAe6f611
export const LEGACY_BRIDGE_EXECUTOR = '0x7d9103572bE58FfE99dc390E8246f02dcAe6f611';

export const CHAIN_ID = 42161;
