// SPDX-License-Identifier: MIT
pragma solidity ^0.8.0;

library ProtocolGuardians {
  // https://etherscan.io/address/0x2CFe3ec4d5a6811f4B8067F0DE7e47DfA938Aa30
  address public constant ETHEREUM_GUARDIAN = 0x2CFe3ec4d5a6811f4B8067F0DE7e47DfA938Aa30;
  // https://polygonscan.com/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
  address public constant POLYGON_GUARDIAN = 0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6;
  // https://snowtrace.io/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
  address public constant AVALANCHE_GUARDIAN = 0x56C1a4b54921DEA9A344967a8693C7E661D72968;
  // https://optimistic.etherscan.io/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
  address public constant OPTIMISM_GUARDIAN = 0x56C1a4b54921DEA9A344967a8693C7E661D72968;
  // https://arbiscan.io/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
  address public constant ARBITRUM_GUARDIAN = 0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6;
  // https://basescan.org/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
  address public constant BASE_GUARDIAN = 0x56C1a4b54921DEA9A344967a8693C7E661D72968;
  // https://gnosisscan.io/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
  address public constant GNOSIS_GUARDIAN = 0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6;
  // https://scrollscan.com/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
  address public constant SCROLL_GUARDIAN = 0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6;
  // https://andromeda-explorer.metis.io/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
  address public constant METIS_GUARDIAN = 0x56C1a4b54921DEA9A344967a8693C7E661D72968;
  // https://bscscan.com/address/0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6
  address public constant BNB_GUARDIAN = 0xCb45E82419baeBCC9bA8b1e5c7858e48A3B26Ea6;
}
library GovernanceGuardians {
  // https://etherscan.io/address/0xCe52ab41C40575B072A18C9700091Ccbe4A06710
  address public constant ETHEREUM_GUARDIAN = 0xCe52ab41C40575B072A18C9700091Ccbe4A06710;
  // https://polygonscan.com/address/0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b
  address public constant POLYGON_GUARDIAN = 0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b;
  // https://snowtrace.io/address/0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe
  address public constant AVALANCHE_GUARDIAN = 0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe;
  // https://optimistic.etherscan.io/address/0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe
  address public constant OPTIMISM_GUARDIAN = 0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe;
  // https://arbiscan.io/address/0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b
  address public constant ARBITRUM_GUARDIAN = 0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b;
  // https://basescan.org/address/0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe
  address public constant BASE_GUARDIAN = 0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe;
  // https://gnosisscan.io/address/0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b
  address public constant GNOSIS_GUARDIAN = 0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b;
  // https://scrollscan.com/address/0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b
  address public constant SCROLL_GUARDIAN = 0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b;
  // https://andromeda-explorer.metis.io/address/0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe
  address public constant METIS_GUARDIAN = 0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe;
  // https://bscscan.com/address/0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b
  address public constant BNB_GUARDIAN = 0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b;
}
