// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

import {IPoolAddressesProvider, IPool, IPoolConfigurator, IAaveOracle, IPoolDataProvider, IACLManager} from './AaveV3.sol';
import {ICollector} from './common/ICollector.sol';

library AaveV3Mumbai {
  // https://mumbai.polygonscan.com/address/0x4CeDCB57Af02293231BAA9D39354D6BFDFD251e0
  IPoolAddressesProvider internal constant POOL_ADDRESSES_PROVIDER =
    IPoolAddressesProvider(0x4CeDCB57Af02293231BAA9D39354D6BFDFD251e0);

  // https://mumbai.polygonscan.com/address/0xcC6114B983E4Ed2737E9BD3961c9924e6216c704
  IPool internal constant POOL = IPool(0xcC6114B983E4Ed2737E9BD3961c9924e6216c704);

  // https://mumbai.polygonscan.com/address/0xBAdD48c3EB42A10dB791D7b02E3c07Fbf95B3155
  address internal constant POOL_IMPL = 0xBAdD48c3EB42A10dB791D7b02E3c07Fbf95B3155;

  // https://mumbai.polygonscan.com/address/0x5C12526EaAc2637fEa2322ee4e389698dBFC3845
  IPoolConfigurator internal constant POOL_CONFIGURATOR =
    IPoolConfigurator(0x5C12526EaAc2637fEa2322ee4e389698dBFC3845);

  // https://mumbai.polygonscan.com/address/0xe6c0e5085CaebcFD5d8a144636dCc2379b38333F
  address internal constant POOL_CONFIGURATOR_IMPL = 0xe6c0e5085CaebcFD5d8a144636dCc2379b38333F;

  // https://mumbai.polygonscan.com/address/0x27848354d8c9f71a41c6f6edfC6E3CACf3b848c8
  IAaveOracle internal constant ORACLE = IAaveOracle(0x27848354d8c9f71a41c6f6edfC6E3CACf3b848c8);

  // https://mumbai.polygonscan.com/address/0x9e2DDb6aA91399546Bd875E2e63E8d6df276922e
  IPoolDataProvider internal constant AAVE_PROTOCOL_DATA_PROVIDER =
    IPoolDataProvider(0x9e2DDb6aA91399546Bd875E2e63E8d6df276922e);

  // https://mumbai.polygonscan.com/address/0x9c2B4870C8ABA221DAe5c82e1a0f72D85e40C165
  IACLManager internal constant ACL_MANAGER =
    IACLManager(0x9c2B4870C8ABA221DAe5c82e1a0f72D85e40C165);

  // https://mumbai.polygonscan.com/address/0x9973Ce75946D56fA3B0C6aa3647d67D440BDAec8
  address internal constant ACL_ADMIN = 0x9973Ce75946D56fA3B0C6aa3647d67D440BDAec8;

  // https://mumbai.polygonscan.com/address/0x742fe7A795439006371705Ceb1c3B075a300ACFc
  ICollector internal constant COLLECTOR = ICollector(0x742fe7A795439006371705Ceb1c3B075a300ACFc);

  // https://mumbai.polygonscan.com/address/0xBcEF55508Efb890C71c8a6211B3dE02B00430503
  address internal constant DEFAULT_INCENTIVES_CONTROLLER =
    0xBcEF55508Efb890C71c8a6211B3dE02B00430503;

  // https://mumbai.polygonscan.com/address/0x274032E998ea08EAE819E7985488AD54DC813b69
  address internal constant DEFAULT_A_TOKEN_IMPL_REV_1 = 0x274032E998ea08EAE819E7985488AD54DC813b69;

  // https://mumbai.polygonscan.com/address/0xf24dc19cFb9A25bbc4DDcaAdb116DfD17472207B
  address internal constant DEFAULT_VARIABLE_DEBT_TOKEN_IMPL_REV_1 =
    0xf24dc19cFb9A25bbc4DDcaAdb116DfD17472207B;

  // https://mumbai.polygonscan.com/address/0xd2B0C9778d088Fc79C28Da719bC02158E64796bD
  address internal constant DEFAULT_STABLE_DEBT_TOKEN_IMPL_REV_1 =
    0xd2B0C9778d088Fc79C28Da719bC02158E64796bD;

  // https://mumbai.polygonscan.com/address/0x9060C6E714BA5C3A46665599103989778a736D4B
  address internal constant EMISSION_MANAGER = 0x9060C6E714BA5C3A46665599103989778a736D4B;

  // https://mumbai.polygonscan.com/address/0x2c95d10bA4BBEc79e562e8B3f48687751808C925
  address internal constant FAUCET = 0x2c95d10bA4BBEc79e562e8B3f48687751808C925;

  // https://mumbai.polygonscan.com/address/0x322bCff7b69F832B1a1F56E6BC600C9229CFb907
  address internal constant UI_INCENTIVE_DATA_PROVIDER = 0x322bCff7b69F832B1a1F56E6BC600C9229CFb907;

  // https://mumbai.polygonscan.com/address/0xD64dDe119f11C88850FD596BE11CE398CC5893e6
  address internal constant UI_POOL_DATA_PROVIDER = 0xD64dDe119f11C88850FD596BE11CE398CC5893e6;

  // https://mumbai.polygonscan.com/address/0xD8A70FC58BC069CFE6529EBF0c1Db067f2b5347E
  address internal constant WALLET_BALANCE_PROVIDER = 0xD8A70FC58BC069CFE6529EBF0c1Db067f2b5347E;

  // https://mumbai.polygonscan.com/address/0x8dA9412AbB78db20d0B496573D9066C474eA21B8
  address internal constant WETH_GATEWAY = 0x8dA9412AbB78db20d0B496573D9066C474eA21B8;

  // https://mumbai.polygonscan.com/address/0x4df6bfA5522aAd4C80e6C95b613B92AC019f2d3e
  address internal constant STATIC_A_TOKEN_FACTORY = 0x4df6bfA5522aAd4C80e6C95b613B92AC019f2d3e;
}

library AaveV3MumbaiAssets {
  // https://mumbai.polygonscan.com/address/0xc8c0Cf9436F4862a8F60Ce680Ca5a9f0f99b5ded
  address internal constant DAI_UNDERLYING = 0xc8c0Cf9436F4862a8F60Ce680Ca5a9f0f99b5ded;

  uint8 internal constant DAI_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0x8903bbBD684B7ef734c01BEb00273Ff52703514F
  address internal constant DAI_A_TOKEN = 0x8903bbBD684B7ef734c01BEb00273Ff52703514F;

  // https://mumbai.polygonscan.com/address/0x8584Fa491eAF3B959dE0888b5B5b9EF60660eb02
  address internal constant DAI_V_TOKEN = 0x8584Fa491eAF3B959dE0888b5B5b9EF60660eb02;

  // https://mumbai.polygonscan.com/address/0xB4aa9399c955C53592D9aF0796AB77709fe184C2
  address internal constant DAI_S_TOKEN = 0xB4aa9399c955C53592D9aF0796AB77709fe184C2;

  // https://mumbai.polygonscan.com/address/0x685b86a6659a1CbcfE168304386e1b54C543Ce16
  address internal constant DAI_ORACLE = 0x685b86a6659a1CbcfE168304386e1b54C543Ce16;

  // https://mumbai.polygonscan.com/address/0xbE46486f69fc2882e5E4769CFBCe704E3EfecD25
  address internal constant DAI_INTEREST_RATE_STRATEGY = 0xbE46486f69fc2882e5E4769CFBCe704E3EfecD25;

  // https://mumbai.polygonscan.com/address/0xe012Fa4A7CAa676b2587A20650b8358d72984250
  address internal constant DAI_STATA_TOKEN = 0xe012Fa4A7CAa676b2587A20650b8358d72984250;

  // https://mumbai.polygonscan.com/address/0x9DFf9E93B1e513379cf820504D642c6891d8F7CC
  address internal constant LINK_UNDERLYING = 0x9DFf9E93B1e513379cf820504D642c6891d8F7CC;

  uint8 internal constant LINK_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0xaB9F0568d5C6CE1437ba07E6efE529A2A9b82665
  address internal constant LINK_A_TOKEN = 0xaB9F0568d5C6CE1437ba07E6efE529A2A9b82665;

  // https://mumbai.polygonscan.com/address/0xC270C1D7B43eE909e5Cb2B59D25033eE79992581
  address internal constant LINK_V_TOKEN = 0xC270C1D7B43eE909e5Cb2B59D25033eE79992581;

  // https://mumbai.polygonscan.com/address/0xe32D202832aE19b06D6D85289f88836D21D51279
  address internal constant LINK_S_TOKEN = 0xe32D202832aE19b06D6D85289f88836D21D51279;

  // https://mumbai.polygonscan.com/address/0xbB96Cf09DaAA98f4dad1f63B0aDeF2C8aaD1BC3E
  address internal constant LINK_ORACLE = 0xbB96Cf09DaAA98f4dad1f63B0aDeF2C8aaD1BC3E;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant LINK_INTEREST_RATE_STRATEGY =
    0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0xA609025Ee8885C4E557331cCF4e3A1099B182359
  address internal constant LINK_STATA_TOKEN = 0xA609025Ee8885C4E557331cCF4e3A1099B182359;

  // https://mumbai.polygonscan.com/address/0x52D800ca262522580CeBAD275395ca6e7598C014
  address internal constant USDC_UNDERLYING = 0x52D800ca262522580CeBAD275395ca6e7598C014;

  uint8 internal constant USDC_DECIMALS = 6;

  // https://mumbai.polygonscan.com/address/0x4086fabeE92a080002eeBA1220B9025a27a40A49
  address internal constant USDC_A_TOKEN = 0x4086fabeE92a080002eeBA1220B9025a27a40A49;

  // https://mumbai.polygonscan.com/address/0x90d909005F13D1Dfd2D8Ab62289309C27E1a066d
  address internal constant USDC_V_TOKEN = 0x90d909005F13D1Dfd2D8Ab62289309C27E1a066d;

  // https://mumbai.polygonscan.com/address/0x0b03Ad2929926505EDE0958EF6454f291808c4c9
  address internal constant USDC_S_TOKEN = 0x0b03Ad2929926505EDE0958EF6454f291808c4c9;

  // https://mumbai.polygonscan.com/address/0x465C5251Ec08Ba64dCDC05833d81e086322dE11F
  address internal constant USDC_ORACLE = 0x465C5251Ec08Ba64dCDC05833d81e086322dE11F;

  // https://mumbai.polygonscan.com/address/0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25
  address internal constant USDC_INTEREST_RATE_STRATEGY =
    0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25;

  // https://mumbai.polygonscan.com/address/0x5eF0fbC8cC652e1128ff50fA8473B7E949C9EaC3
  address internal constant USDC_STATA_TOKEN = 0x5eF0fbC8cC652e1128ff50fA8473B7E949C9EaC3;

  // https://mumbai.polygonscan.com/address/0x2Fa2e7a6dEB7bb51B625336DBe1dA23511914a8A
  address internal constant WBTC_UNDERLYING = 0x2Fa2e7a6dEB7bb51B625336DBe1dA23511914a8A;

  uint8 internal constant WBTC_DECIMALS = 8;

  // https://mumbai.polygonscan.com/address/0xdA67e6C1171D4f0D522Db7f127B88405eA1535d4
  address internal constant WBTC_A_TOKEN = 0xdA67e6C1171D4f0D522Db7f127B88405eA1535d4;

  // https://mumbai.polygonscan.com/address/0x4ac5719fbd9986b17911815058d3D4f50E6608eA
  address internal constant WBTC_V_TOKEN = 0x4ac5719fbd9986b17911815058d3D4f50E6608eA;

  // https://mumbai.polygonscan.com/address/0x56073a5443d271f4A05A7580F23458e0cc292566
  address internal constant WBTC_S_TOKEN = 0x56073a5443d271f4A05A7580F23458e0cc292566;

  // https://mumbai.polygonscan.com/address/0x3E3D70Dc636E98636c68d51Aa4a91D4D1828D277
  address internal constant WBTC_ORACLE = 0x3E3D70Dc636E98636c68d51Aa4a91D4D1828D277;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant WBTC_INTEREST_RATE_STRATEGY =
    0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0x0693e498eF6D6fb27b57dc3D9e3E0a0f9f2fbeC4
  address internal constant WBTC_STATA_TOKEN = 0x0693e498eF6D6fb27b57dc3D9e3E0a0f9f2fbeC4;

  // https://mumbai.polygonscan.com/address/0xc199807AF4fEDB02EE567Ed0FeB814A077de4802
  address internal constant WETH_UNDERLYING = 0xc199807AF4fEDB02EE567Ed0FeB814A077de4802;

  uint8 internal constant WETH_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0xAba444af64ad33A6d8575b8A353226997d6A126a
  address internal constant WETH_A_TOKEN = 0xAba444af64ad33A6d8575b8A353226997d6A126a;

  // https://mumbai.polygonscan.com/address/0x6B9f12aD327e2760816A8a6c7A740AeA901fEB21
  address internal constant WETH_V_TOKEN = 0x6B9f12aD327e2760816A8a6c7A740AeA901fEB21;

  // https://mumbai.polygonscan.com/address/0x7A3e52bd23036004f48D34c946A600688b6861Fe
  address internal constant WETH_S_TOKEN = 0x7A3e52bd23036004f48D34c946A600688b6861Fe;

  // https://mumbai.polygonscan.com/address/0xc24df0548a5aa08262bff6c2bb48048348e4E097
  address internal constant WETH_ORACLE = 0xc24df0548a5aa08262bff6c2bb48048348e4E097;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant WETH_INTEREST_RATE_STRATEGY =
    0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0x666ef6De71Eb3DAd05F996ECAa910360f4e8fD7c
  address internal constant WETH_STATA_TOKEN = 0x666ef6De71Eb3DAd05F996ECAa910360f4e8fD7c;

  // https://mumbai.polygonscan.com/address/0x1fdE0eCc619726f4cD597887C9F3b4c8740e19e2
  address internal constant USDT_UNDERLYING = 0x1fdE0eCc619726f4cD597887C9F3b4c8740e19e2;

  uint8 internal constant USDT_DECIMALS = 6;

  // https://mumbai.polygonscan.com/address/0x5F3a71D07E95C1E54B9Cc055D418a219586A3473
  address internal constant USDT_A_TOKEN = 0x5F3a71D07E95C1E54B9Cc055D418a219586A3473;

  // https://mumbai.polygonscan.com/address/0x04A2bc818911a729460b3FfB4B9ff841CFEC93a1
  address internal constant USDT_V_TOKEN = 0x04A2bc818911a729460b3FfB4B9ff841CFEC93a1;

  // https://mumbai.polygonscan.com/address/0xECe1254ce1cCFc9bA552B827dB0F3c95d72639F1
  address internal constant USDT_S_TOKEN = 0xECe1254ce1cCFc9bA552B827dB0F3c95d72639F1;

  // https://mumbai.polygonscan.com/address/0x17E6574DA37DD6F20d80CBf0d1580a420056413e
  address internal constant USDT_ORACLE = 0x17E6574DA37DD6F20d80CBf0d1580a420056413e;

  // https://mumbai.polygonscan.com/address/0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25
  address internal constant USDT_INTEREST_RATE_STRATEGY =
    0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25;

  // https://mumbai.polygonscan.com/address/0x48774b9D6Bd38d6d0CF17D9C6E023b67eDAEeA29
  address internal constant USDT_STATA_TOKEN = 0x48774b9D6Bd38d6d0CF17D9C6E023b67eDAEeA29;

  // https://mumbai.polygonscan.com/address/0x1558c6FadDe1bEaf0f6628BDd1DFf3461185eA24
  address internal constant AAVE_UNDERLYING = 0x1558c6FadDe1bEaf0f6628BDd1DFf3461185eA24;

  uint8 internal constant AAVE_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0xE05705857b3d78aCe3d872b26D9c951B266ECC8d
  address internal constant AAVE_A_TOKEN = 0xE05705857b3d78aCe3d872b26D9c951B266ECC8d;

  // https://mumbai.polygonscan.com/address/0xe5e880dAd60A9D0f6Cea43a664517F2eb6fe3233
  address internal constant AAVE_V_TOKEN = 0xe5e880dAd60A9D0f6Cea43a664517F2eb6fe3233;

  // https://mumbai.polygonscan.com/address/0x792359Ee24BE0268ffEb3c61425e89550E0872B5
  address internal constant AAVE_S_TOKEN = 0x792359Ee24BE0268ffEb3c61425e89550E0872B5;

  // https://mumbai.polygonscan.com/address/0x1034d6131E0E7F2F47bFAd06597ed97b35aA5492
  address internal constant AAVE_ORACLE = 0x1034d6131E0E7F2F47bFAd06597ed97b35aA5492;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant AAVE_INTEREST_RATE_STRATEGY =
    0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0xC19611D616f191dc7dFFAf192c071B8957379585
  address internal constant AAVE_STATA_TOKEN = 0xC19611D616f191dc7dFFAf192c071B8957379585;

  // https://mumbai.polygonscan.com/address/0xaD3C5a67275dE4b5554CdD1d961e957f408eF75a
  address internal constant WMATIC_UNDERLYING = 0xaD3C5a67275dE4b5554CdD1d961e957f408eF75a;

  uint8 internal constant WMATIC_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0xaCA5e6a7117F54B34B476aB95Bf3034c304e7a81
  address internal constant WMATIC_A_TOKEN = 0xaCA5e6a7117F54B34B476aB95Bf3034c304e7a81;

  // https://mumbai.polygonscan.com/address/0x4d4ADCd160BFA54B7b288537705434c478843b37
  address internal constant WMATIC_V_TOKEN = 0x4d4ADCd160BFA54B7b288537705434c478843b37;

  // https://mumbai.polygonscan.com/address/0x0b7F789EDb7B72c98eD7290fB1286239C4965713
  address internal constant WMATIC_S_TOKEN = 0x0b7F789EDb7B72c98eD7290fB1286239C4965713;

  // https://mumbai.polygonscan.com/address/0x365691299B5DCFFEFF045018C4DD97c17f2DF10E
  address internal constant WMATIC_ORACLE = 0x365691299B5DCFFEFF045018C4DD97c17f2DF10E;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant WMATIC_INTEREST_RATE_STRATEGY =
    0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0x5C0478fd615e02ecC3BB3fbe2fe6153090031696
  address internal constant WMATIC_STATA_TOKEN = 0x5C0478fd615e02ecC3BB3fbe2fe6153090031696;

  // https://mumbai.polygonscan.com/address/0x2bbF1f48a678d2f7c291dc5F8fD04805D34F485f
  address internal constant CRV_UNDERLYING = 0x2bbF1f48a678d2f7c291dc5F8fD04805D34F485f;

  uint8 internal constant CRV_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0xbB814C46ef7BFB51E3b25600675A6A7B03426973
  address internal constant CRV_A_TOKEN = 0xbB814C46ef7BFB51E3b25600675A6A7B03426973;

  // https://mumbai.polygonscan.com/address/0xb9bA8eb73F06cC77Ec761485872005b228873DA6
  address internal constant CRV_V_TOKEN = 0xb9bA8eb73F06cC77Ec761485872005b228873DA6;

  // https://mumbai.polygonscan.com/address/0xA342ffE4BC6a7159021A0099357dB919FC3965d7
  address internal constant CRV_S_TOKEN = 0xA342ffE4BC6a7159021A0099357dB919FC3965d7;

  // https://mumbai.polygonscan.com/address/0x44c4c82FEe3d9c5A3A584e87D4c0dAe14c4D880C
  address internal constant CRV_ORACLE = 0x44c4c82FEe3d9c5A3A584e87D4c0dAe14c4D880C;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant CRV_INTEREST_RATE_STRATEGY = 0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0x81E7EB2067FDc31308b2dC97A070EDe0634Aa7fd
  address internal constant CRV_STATA_TOKEN = 0x81E7EB2067FDc31308b2dC97A070EDe0634Aa7fd;

  // https://mumbai.polygonscan.com/address/0x3c9F4EEa18B02ee331218646Fea59EE3661d2A61
  address internal constant SUSHI_UNDERLYING = 0x3c9F4EEa18B02ee331218646Fea59EE3661d2A61;

  uint8 internal constant SUSHI_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0x474Af312bbfc1d12b6f6e2140D6D50Ed9dA6F839
  address internal constant SUSHI_A_TOKEN = 0x474Af312bbfc1d12b6f6e2140D6D50Ed9dA6F839;

  // https://mumbai.polygonscan.com/address/0x586Ccc2Ca7840E860d741ddfbFf390da0fB42B95
  address internal constant SUSHI_V_TOKEN = 0x586Ccc2Ca7840E860d741ddfbFf390da0fB42B95;

  // https://mumbai.polygonscan.com/address/0x5d7ca2fF15be1C22669d25F0CA42541AF8B7c46D
  address internal constant SUSHI_S_TOKEN = 0x5d7ca2fF15be1C22669d25F0CA42541AF8B7c46D;

  // https://mumbai.polygonscan.com/address/0x18a8d31dA46eeb9138a16dfC429E74C04ff523F4
  address internal constant SUSHI_ORACLE = 0x18a8d31dA46eeb9138a16dfC429E74C04ff523F4;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant SUSHI_INTEREST_RATE_STRATEGY =
    0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0xDEF3d6FcFD68af03cCC4818FFd17F57A54Dd93f8
  address internal constant SUSHI_STATA_TOKEN = 0xDEF3d6FcFD68af03cCC4818FFd17F57A54Dd93f8;

  // https://mumbai.polygonscan.com/address/0x9f86bA35a016acE27BD4C37E42a1940A5b2508EF
  address internal constant GHST_UNDERLYING = 0x9f86bA35a016acE27BD4C37E42a1940A5b2508EF;

  uint8 internal constant GHST_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0x9B1330b35DD740242c4622b5f203Bc39Ff40D9c9
  address internal constant GHST_A_TOKEN = 0x9B1330b35DD740242c4622b5f203Bc39Ff40D9c9;

  // https://mumbai.polygonscan.com/address/0xd8Aab78Fe045D67b463f0361578e01c40CbFb4B7
  address internal constant GHST_V_TOKEN = 0xd8Aab78Fe045D67b463f0361578e01c40CbFb4B7;

  // https://mumbai.polygonscan.com/address/0x7195f1F8EA840AD7A0dF705a929667bFcCF90814
  address internal constant GHST_S_TOKEN = 0x7195f1F8EA840AD7A0dF705a929667bFcCF90814;

  // https://mumbai.polygonscan.com/address/0x0EFC6aec29cE36fdEB293491f8F77650Eb1A82F4
  address internal constant GHST_ORACLE = 0x0EFC6aec29cE36fdEB293491f8F77650Eb1A82F4;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant GHST_INTEREST_RATE_STRATEGY =
    0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0x7f178E419181B8C9CF64fee7D58F24b32ec0F1cc
  address internal constant GHST_STATA_TOKEN = 0x7f178E419181B8C9CF64fee7D58F24b32ec0F1cc;

  // https://mumbai.polygonscan.com/address/0x00DF377c2C82a65A8bAe2Ff04a9434a721Bc5aEB
  address internal constant BAL_UNDERLYING = 0x00DF377c2C82a65A8bAe2Ff04a9434a721Bc5aEB;

  uint8 internal constant BAL_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0x27EbCb5ba3e4Ab18911dA0bA3350Ec42ceEa4ceE
  address internal constant BAL_A_TOKEN = 0x27EbCb5ba3e4Ab18911dA0bA3350Ec42ceEa4ceE;

  // https://mumbai.polygonscan.com/address/0x92cCc1f6A3DA79eD405e7b5AFaF3BA54Ba5408F5
  address internal constant BAL_V_TOKEN = 0x92cCc1f6A3DA79eD405e7b5AFaF3BA54Ba5408F5;

  // https://mumbai.polygonscan.com/address/0xf0D2C1971709aE77207A0b9D924a1374642d8E4c
  address internal constant BAL_S_TOKEN = 0xf0D2C1971709aE77207A0b9D924a1374642d8E4c;

  // https://mumbai.polygonscan.com/address/0xdBfA358282bf03c67B059063fBc71b40ddFeDf1f
  address internal constant BAL_ORACLE = 0xdBfA358282bf03c67B059063fBc71b40ddFeDf1f;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant BAL_INTEREST_RATE_STRATEGY = 0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0xb95140824eC44ec97ab10f459aD0768275Eb3e94
  address internal constant BAL_STATA_TOKEN = 0xb95140824eC44ec97ab10f459aD0768275Eb3e94;

  // https://mumbai.polygonscan.com/address/0x55c7852e10fcd07cF63Ad1bb9FC191b6F4d96ebD
  address internal constant DPI_UNDERLYING = 0x55c7852e10fcd07cF63Ad1bb9FC191b6F4d96ebD;

  uint8 internal constant DPI_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0xeBf20b66BB82a157450C3ad4cab738D629a29749
  address internal constant DPI_A_TOKEN = 0xeBf20b66BB82a157450C3ad4cab738D629a29749;

  // https://mumbai.polygonscan.com/address/0xf415b985e0CA9850Ae1C04081DF8DeD8bD5ef8e5
  address internal constant DPI_V_TOKEN = 0xf415b985e0CA9850Ae1C04081DF8DeD8bD5ef8e5;

  // https://mumbai.polygonscan.com/address/0x710Fe3223CcB7C3987C3fD0c0EFA89201a3C8E22
  address internal constant DPI_S_TOKEN = 0x710Fe3223CcB7C3987C3fD0c0EFA89201a3C8E22;

  // https://mumbai.polygonscan.com/address/0xD5D4f4fe4BfC8e8193f38927EfafDbfbB66dd7e0
  address internal constant DPI_ORACLE = 0xD5D4f4fe4BfC8e8193f38927EfafDbfbB66dd7e0;

  // https://mumbai.polygonscan.com/address/0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B
  address internal constant DPI_INTEREST_RATE_STRATEGY = 0x0313912C1C3D946F9253D9b6E9f6aB9137759b4B;

  // https://mumbai.polygonscan.com/address/0x00718266Ae6AbaCe3C14AD0263968eB7F581BC91
  address internal constant DPI_STATA_TOKEN = 0x00718266Ae6AbaCe3C14AD0263968eB7F581BC91;

  // https://mumbai.polygonscan.com/address/0xB516d30421d2A0524769A243BBE5e193E78ab35c
  address internal constant EURS_UNDERLYING = 0xB516d30421d2A0524769A243BBE5e193E78ab35c;

  uint8 internal constant EURS_DECIMALS = 2;

  // https://mumbai.polygonscan.com/address/0x6fD1376295392f1F6F9EcCc89bff0e26dDB2aE74
  address internal constant EURS_A_TOKEN = 0x6fD1376295392f1F6F9EcCc89bff0e26dDB2aE74;

  // https://mumbai.polygonscan.com/address/0x6e87Cad75af55fc5611D3a90d6789B12A87E72e4
  address internal constant EURS_V_TOKEN = 0x6e87Cad75af55fc5611D3a90d6789B12A87E72e4;

  // https://mumbai.polygonscan.com/address/0x9a8c655A5Bf29C4B2bBcb45e838CC07DceB680E1
  address internal constant EURS_S_TOKEN = 0x9a8c655A5Bf29C4B2bBcb45e838CC07DceB680E1;

  // https://mumbai.polygonscan.com/address/0x09Bb4317F42FA4eA4d044922f795bf6ccFeAAA4b
  address internal constant EURS_ORACLE = 0x09Bb4317F42FA4eA4d044922f795bf6ccFeAAA4b;

  // https://mumbai.polygonscan.com/address/0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25
  address internal constant EURS_INTEREST_RATE_STRATEGY =
    0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25;

  // https://mumbai.polygonscan.com/address/0xB5B6c7a13602CF827Cc2F0383E27F8e2DB8dBE64
  address internal constant EURS_STATA_TOKEN = 0xB5B6c7a13602CF827Cc2F0383E27F8e2DB8dBE64;

  // https://mumbai.polygonscan.com/address/0xd409F17095a370800A9C352124C6a1e82695203E
  address internal constant JEUR_UNDERLYING = 0xd409F17095a370800A9C352124C6a1e82695203E;

  uint8 internal constant JEUR_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0x58B8d2A77D7d5942fA701a1Dd68e7cF8222750f6
  address internal constant JEUR_A_TOKEN = 0x58B8d2A77D7d5942fA701a1Dd68e7cF8222750f6;

  // https://mumbai.polygonscan.com/address/0xaCD2c77bd160297C151CC22eB6A3C1c77723f02c
  address internal constant JEUR_V_TOKEN = 0xaCD2c77bd160297C151CC22eB6A3C1c77723f02c;

  // https://mumbai.polygonscan.com/address/0x0736CBe1647b8E223Bb74D8E1FE53D14ADfc763e
  address internal constant JEUR_S_TOKEN = 0x0736CBe1647b8E223Bb74D8E1FE53D14ADfc763e;

  // https://mumbai.polygonscan.com/address/0x67cEB95eCD290A25D017B0f4D345E5F7Ba893B5F
  address internal constant JEUR_ORACLE = 0x67cEB95eCD290A25D017B0f4D345E5F7Ba893B5F;

  // https://mumbai.polygonscan.com/address/0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25
  address internal constant JEUR_INTEREST_RATE_STRATEGY =
    0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25;

  // https://mumbai.polygonscan.com/address/0xEf6F8a13a8B2098F13D08A95b32191ddE13693eE
  address internal constant JEUR_STATA_TOKEN = 0xEf6F8a13a8B2098F13D08A95b32191ddE13693eE;

  // https://mumbai.polygonscan.com/address/0xcDA8dE50b65cB2Affc8B89f35C40A97Eed4B270F
  address internal constant AGEUR_UNDERLYING = 0xcDA8dE50b65cB2Affc8B89f35C40A97Eed4B270F;

  uint8 internal constant AGEUR_DECIMALS = 18;

  // https://mumbai.polygonscan.com/address/0xbD3615332c2a12e2fFc41Fe09C4f05e5493e733F
  address internal constant AGEUR_A_TOKEN = 0xbD3615332c2a12e2fFc41Fe09C4f05e5493e733F;

  // https://mumbai.polygonscan.com/address/0x7511Bc35eDfb9513e67a6431826C766c24401AeF
  address internal constant AGEUR_V_TOKEN = 0x7511Bc35eDfb9513e67a6431826C766c24401AeF;

  // https://mumbai.polygonscan.com/address/0xbaF52AEC0fAC8f4bFD8cD05AE1D5729a2b82051b
  address internal constant AGEUR_S_TOKEN = 0xbaF52AEC0fAC8f4bFD8cD05AE1D5729a2b82051b;

  // https://mumbai.polygonscan.com/address/0xCf9DADD5cFE871f65D7EeFAEbe44481c8597b26e
  address internal constant AGEUR_ORACLE = 0xCf9DADD5cFE871f65D7EeFAEbe44481c8597b26e;

  // https://mumbai.polygonscan.com/address/0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25
  address internal constant AGEUR_INTEREST_RATE_STRATEGY =
    0x8d284fE251BB7Fe6B529FC2f27BAb415FcF46B25;

  // https://mumbai.polygonscan.com/address/0xeF5074Dd60e25F8EFd763068C73d34E05815f41f
  address internal constant AGEUR_STATA_TOKEN = 0xeF5074Dd60e25F8EFd763068C73d34E05815f41f;
}

library AaveV3MumbaiEModes {
  uint8 internal constant NONE = 0;

  uint8 internal constant STABLECOINS = 1;
}
