// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
import {IGovernanceCore, IPayloadsControllerCore, IDataWarehouse, IVotingStrategy} from './GovernanceV3.sol';
library GovernanceV3Scroll {
  // https://scrollscan.com/address/0x03073D3F4769f6b6604d616238fD6c636C99AD0A
  address internal constant CROSS_CHAIN_CONTROLLER = 0x03073D3F4769f6b6604d616238fD6c636C99AD0A;

  // https://scrollscan.com/address/0x6b6B41c0f8C223715f712BE83ceC3c37bbfDC3fE
  IPayloadsControllerCore internal constant PAYLOADS_CONTROLLER =
    IPayloadsControllerCore(0x6b6B41c0f8C223715f712BE83ceC3c37bbfDC3fE);

  // https://scrollscan.com/address/0xf438e33dCCEE260ee4371F9dceF408b0d7DBe424
  address internal constant PC_DATA_HELPER = 0xf438e33dCCEE260ee4371F9dceF408b0d7DBe424;

  // https://scrollscan.com/address/0xa835707d28e6C37C49d661742f2Fb5987367cEd4
  address internal constant GRANULAR_GUARDIAN = 0xa835707d28e6C37C49d661742f2Fb5987367cEd4;

  // https://scrollscan.com/address/0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b
  address internal constant GOVERNANCE_GUARDIAN = 0x1A0581dd5C7C3DA4Ba1CDa7e0BcA7286afc4973b;

  // https://scrollscan.com/address/0xc1ABF87FfAdf4908f4eC8dc54A25DCFEabAE4A24
  address internal constant EXECUTOR_LVL_1 = 0xc1ABF87FfAdf4908f4eC8dc54A25DCFEabAE4A24;
}
