// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://era.zksync.network/address/0x903A3228c4C58e94787CB33EE83e087bCFcF0a91
export const TRANSPARENT_PROXY_FACTORY = '0x903A3228c4C58e94787CB33EE83e087bCFcF0a91';

// https://era.zksync.network/address/0x158d6c497317367CEa3CBAb0BD84E6de236F060D
export const PROXY_ADMIN = '0x158d6c497317367CEa3CBAb0BD84E6de236F060D';

// https://era.zksync.network/address/0xba845c27903F7dDB5c676e5b74728C871057E000
export const PROTOCOL_GUARDIAN = '0xba845c27903F7dDB5c676e5b74728C871057E000';

export const CHAIN_ID = 324;
