// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscAvalanche {
  // https://snowtrace.io/address/0x9abf798f5314BFd793A9E57A654BEd35af4A1D60
  address internal constant PARASWAP_FEE_CLAIMER = 0x9abf798f5314BFd793A9E57A654BEd35af4A1D60;

  // https://snowtrace.io/address/0xB4e496f70602fE2AC6Ae511D028BA4D194773B29
  address internal constant TRANSPARENT_PROXY_FACTORY = 0xB4e496f70602fE2AC6Ae511D028BA4D194773B29;

  // https://snowtrace.io/address/0xD3cF979e676265e4f6379749DECe4708B9A22476
  address internal constant PROXY_ADMIN = 0xD3cF979e676265e4f6379749DECe4708B9A22476;

  // https://snowtrace.io/address/0x3b56998Ec06477704622ca8e2eA1b4db134cec32
  address internal constant CREATE_3_FACTORY = 0x3b56998Ec06477704622ca8e2eA1b4db134cec32;

  // https://snowtrace.io/address/0x06d958772304e7220fc3E463756CE01Ed0D24db2
  address internal constant AAVE_CL_ROBOT_OPERATOR = 0x06d958772304e7220fc3E463756CE01Ed0D24db2;

  // https://snowtrace.io/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
  address internal constant PROTOCOL_GUARDIAN = 0x56C1a4b54921DEA9A344967a8693C7E661D72968;

  // https://snowtrace.io/address/0xA065d5A299E618CD84a87641d5eEbC7916Fdf32E
  address internal constant AAVE_MERKLE_DISTRIBUTOR = 0xA065d5A299E618CD84a87641d5eEbC7916Fdf32E;
}
