// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
import {IGovernanceCore, IPayloadsControllerCore, IDataWarehouse, IVotingStrategy} from './GovernanceV3.sol';
library GovernanceV3Ethereum {
  // https://etherscan.io/address/0xEd42a7D8559a463722Ca4beD50E0Cc05a386b0e1
  address internal constant CROSS_CHAIN_CONTROLLER = 0xEd42a7D8559a463722Ca4beD50E0Cc05a386b0e1;

  // https://etherscan.io/address/0x9AEE0B04504CeF83A65AC3f0e838D0593BCb2BC7
  IGovernanceCore internal constant GOVERNANCE =
    IGovernanceCore(0x9AEE0B04504CeF83A65AC3f0e838D0593BCb2BC7);

  // https://etherscan.io/address/0xdAbad81aF85554E9ae636395611C58F7eC1aAEc5
  IPayloadsControllerCore internal constant PAYLOADS_CONTROLLER =
    IPayloadsControllerCore(0xdAbad81aF85554E9ae636395611C58F7eC1aAEc5);

  // https://etherscan.io/address/0x617332a777780F546261247F621051d0b98975Eb
  address internal constant VOTING_MACHINE = 0x617332a777780F546261247F621051d0b98975Eb;

  // https://etherscan.io/address/0xf23f7De3AC42F22eBDA17e64DC4f51FB66b8E21f
  address internal constant VOTING_PORTAL_ETH_ETH = 0xf23f7De3AC42F22eBDA17e64DC4f51FB66b8E21f;

  // https://etherscan.io/address/0x33aCEf7365809218485873B7d0d67FeE411B5D79
  address internal constant VOTING_PORTAL_ETH_AVAX = 0x33aCEf7365809218485873B7d0d67FeE411B5D79;

  // https://etherscan.io/address/0x9b24C168d6A76b5459B1d47071a54962a4df36c3
  address internal constant VOTING_PORTAL_ETH_POL = 0x9b24C168d6A76b5459B1d47071a54962a4df36c3;

  // https://etherscan.io/address/0xE3B770Dc4ae3f8bECaB3Ed12dE692c741603e16A
  address internal constant PC_DATA_HELPER = 0xE3B770Dc4ae3f8bECaB3Ed12dE692c741603e16A;

  // https://etherscan.io/address/0x971c82c8316aD611904F95616c21ce90837f1856
  address internal constant GOV_DATA_HELPER = 0x971c82c8316aD611904F95616c21ce90837f1856;

  // https://etherscan.io/address/0x77976B51569896523EE215962Ee91ff236Fa50E8
  address internal constant VM_DATA_HELPER = 0x77976B51569896523EE215962Ee91ff236Fa50E8;

  // https://etherscan.io/address/0x94363B11b37BC3ffe43AB09cff5A010352FE85dC
  address internal constant META_DELEGATE_HELPER = 0x94363B11b37BC3ffe43AB09cff5A010352FE85dC;

  // https://etherscan.io/address/0x73C6Fb358dDA8e84D50e98A98F7c0dF32e15C7e9
  address internal constant EMERGENCY_REGISTRY = 0x73C6Fb358dDA8e84D50e98A98F7c0dF32e15C7e9;

  // https://etherscan.io/address/0xa198Fac58E02A5C5F8F7e877895d50cFa9ad1E04
  address internal constant GOVERNANCE_POWER_STRATEGY = 0xa198Fac58E02A5C5F8F7e877895d50cFa9ad1E04;

  // https://etherscan.io/address/0x4457cA11E90f416Cc1D3a8E1cA41C0cdEcC251d4
  address internal constant GRANULAR_GUARDIAN = 0x4457cA11E90f416Cc1D3a8E1cA41C0cdEcC251d4;

  // https://etherscan.io/address/0xCe52ab41C40575B072A18C9700091Ccbe4A06710
  address internal constant GOVERNANCE_GUARDIAN = 0xCe52ab41C40575B072A18C9700091Ccbe4A06710;

  // https://etherscan.io/address/0x5300A1a15135EA4dc7aD5a167152C01EFc9b192A
  address internal constant EXECUTOR_LVL_1 = 0x5300A1a15135EA4dc7aD5a167152C01EFc9b192A;

  // https://etherscan.io/address/0x17Dd33Ed0e3dD2a80E37489B8A63063161BE6957
  address internal constant EXECUTOR_LVL_2 = 0x17Dd33Ed0e3dD2a80E37489B8A63063161BE6957;

  // https://etherscan.io/address/0x5642A5A5Ec284B4145563aBF319620204aCCA7f4
  IVotingStrategy internal constant VOTING_STRATEGY =
    IVotingStrategy(0x5642A5A5Ec284B4145563aBF319620204aCCA7f4);

  // https://etherscan.io/address/0x1699FE9CaDC8a0b6c93E06B62Ab4592a0fFEcF61
  IDataWarehouse internal constant DATA_WAREHOUSE =
    IDataWarehouse(0x1699FE9CaDC8a0b6c93E06B62Ab4592a0fFEcF61);
}
