import {ConfigFile} from '../../generator/types';
export const config: ConfigFile = {
  rootOptions: {
    author: 'BGD Labs @bgdlabs',
    pools: [
      'AaveV2Ethereum',
      'AaveV2EthereumAMM',
      'AaveV2Polygon',
      'AaveV2Avalanche',
      'AaveV3Ethereum',
      'AaveV3Polygon',
      'AaveV3Avalanche',
      'AaveV3Optimism',
      'AaveV3Arbitrum',
      'AaveV3Metis',
      'AaveV3Base',
      'AaveV3Gnosis',
      'AaveV3Scroll',
      'AaveV3BNB',
    ],
    title: 'Update legacy guardian',
    shortName: 'UpdateLegacyGuardian',
    date: '20241016',
    discussion: 'https://governance.aave.com/t/bgd-technical-maintenance-proposals/15274/48',
    snapshot: '',
    votingNetwork: 'POLYGON',
  },
  poolOptions: {
    AaveV2Ethereum: {configs: {OTHERS: {}}, cache: {blockNumber: 20977043}},
    AaveV2EthereumAMM: {configs: {OTHERS: {}}, cache: {blockNumber: 20977044}},
    AaveV2Polygon: {configs: {OTHERS: {}}, cache: {blockNumber: 63102393}},
    AaveV2Avalanche: {configs: {}, cache: {blockNumber: 51845038}},
    AaveV3Ethereum: {configs: {OTHERS: {}}, cache: {blockNumber: 20977044}},
    AaveV3Polygon: {configs: {OTHERS: {}}, cache: {blockNumber: 63102404}},
    AaveV3Avalanche: {configs: {OTHERS: {}}, cache: {blockNumber: 51845051}},
    AaveV3Optimism: {configs: {OTHERS: {}}, cache: {blockNumber: 126734965}},
    AaveV3Arbitrum: {configs: {OTHERS: {}}, cache: {blockNumber: 264358356}},
    AaveV3Metis: {configs: {OTHERS: {}}, cache: {blockNumber: 18729457}},
    AaveV3Base: {configs: {OTHERS: {}}, cache: {blockNumber: 21139687}},
    AaveV3Gnosis: {configs: {OTHERS: {}}, cache: {blockNumber: 36531561}},
    AaveV3Scroll: {configs: {OTHERS: {}}, cache: {blockNumber: 10212748}},
    AaveV3BNB: {configs: {OTHERS: {}}, cache: {blockNumber: 43162950}},
  },
};
