// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
export const AggregatorInterface_ABI = [
  {
    type: 'function',
    name: 'getAnswer',
    inputs: [
      {
        name: 'roundId',
        type: 'uint256',
        internalType: 'uint256',
      },
    ],
    outputs: [
      {
        name: '',
        type: 'int256',
        internalType: 'int256',
      },
    ],
    stateMutability: 'view',
  },
  {
    type: 'function',
    name: 'getTimestamp',
    inputs: [
      {
        name: 'roundId',
        type: 'uint256',
        internalType: 'uint256',
      },
    ],
    outputs: [
      {
        name: '',
        type: 'uint256',
        internalType: 'uint256',
      },
    ],
    stateMutability: 'view',
  },
  {
    type: 'function',
    name: 'latestAnswer',
    inputs: [],
    outputs: [
      {
        name: '',
        type: 'int256',
        internalType: 'int256',
      },
    ],
    stateMutability: 'view',
  },
  {
    type: 'function',
    name: 'latestRound',
    inputs: [],
    outputs: [
      {
        name: '',
        type: 'uint256',
        internalType: 'uint256',
      },
    ],
    stateMutability: 'view',
  },
  {
    type: 'function',
    name: 'latestTimestamp',
    inputs: [],
    outputs: [
      {
        name: '',
        type: 'uint256',
        internalType: 'uint256',
      },
    ],
    stateMutability: 'view',
  },
  {
    type: 'event',
    name: 'AnswerUpdated',
    inputs: [
      {
        name: 'current',
        type: 'int256',
        indexed: true,
        internalType: 'int256',
      },
      {
        name: 'roundId',
        type: 'uint256',
        indexed: true,
        internalType: 'uint256',
      },
      {
        name: 'updatedAt',
        type: 'uint256',
        indexed: false,
        internalType: 'uint256',
      },
    ],
    anonymous: false,
  },
  {
    type: 'event',
    name: 'NewRound',
    inputs: [
      {
        name: 'roundId',
        type: 'uint256',
        indexed: true,
        internalType: 'uint256',
      },
      {
        name: 'startedBy',
        type: 'address',
        indexed: true,
        internalType: 'address',
      },
      {
        name: 'startedAt',
        type: 'uint256',
        indexed: false,
        internalType: 'uint256',
      },
    ],
    anonymous: false,
  },
] as const;
