// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
import {IGovernanceCore, IPayloadsControllerCore, IDataWarehouse, IVotingStrategy} from './GovernanceV3.sol';
library GovernanceV3Fuji {
  // https://testnet.snowtrace.io/address/0x5488A48E5C22175548E8d68622211F5928cBbf23
  address internal constant CROSS_CHAIN_CONTROLLER = 0x5488A48E5C22175548E8d68622211F5928cBbf23;

  // https://testnet.snowtrace.io/address/0x79Edd77c76F95b6b69907CaD1d8241F9DB0e3FD0
  address internal constant VOTING_MACHINE = 0x79Edd77c76F95b6b69907CaD1d8241F9DB0e3FD0;

  // https://testnet.snowtrace.io/address/0xf1842f9D6C3D9ec1153d7afCBb9cDBC537Ea5d15
  IPayloadsControllerCore internal constant PAYLOADS_CONTROLLER =
    IPayloadsControllerCore(0xf1842f9D6C3D9ec1153d7afCBb9cDBC537Ea5d15);

  // https://testnet.snowtrace.io/address/0xACd2b1bA0B85FaF0f45D4974Ba8ee538E157fBc6
  address internal constant EXECUTOR_LVL_1 = 0xACd2b1bA0B85FaF0f45D4974Ba8ee538E157fBc6;

  // https://testnet.snowtrace.io/address/0x8c55a1bf3DC7076522C5cd025f497A498eF90143
  IVotingStrategy internal constant VOTING_STRATEGY =
    IVotingStrategy(0x8c55a1bf3DC7076522C5cd025f497A498eF90143);

  // https://testnet.snowtrace.io/address/0xDB23939d4C483E748c2487916fB20d7fF7e39588
  IDataWarehouse internal constant DATA_WAREHOUSE =
    IDataWarehouse(0xDB23939d4C483E748c2487916fB20d7fF7e39588);
}
