// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

import {GovernanceV3Ethereum} from './GovernanceV3Ethereum.sol';
import {GovernanceV3Arbitrum} from './GovernanceV3Arbitrum.sol';
import {GovernanceV3Avalanche} from './GovernanceV3Avalanche.sol';
import {GovernanceV3Fuji} from './GovernanceV3Fuji.sol';
import {GovernanceV3Optimism} from './GovernanceV3Optimism.sol';
import {GovernanceV3Polygon} from './GovernanceV3Polygon.sol';
import {GovernanceV3Metis} from './GovernanceV3Metis.sol';
import {GovernanceV3Base} from './GovernanceV3Base.sol';
import {GovernanceV3BNB} from './GovernanceV3BNB.sol';
import {GovernanceV3Gnosis} from './GovernanceV3Gnosis.sol';
import {GovernanceV3Scroll} from './GovernanceV3Scroll.sol';
import {GovernanceV3PolygonZkEvm} from './GovernanceV3PolygonZkEvm.sol';
import {GovernanceV3ZkSync} from './GovernanceV3ZkSync.sol';
import {AaveV1} from './AaveV1.sol';
import {AaveV2EthereumAMM} from './AaveV2EthereumAMM.sol';
import {AaveV2EthereumArc} from './AaveV2EthereumArc.sol';
import {AaveV2Ethereum} from './AaveV2Ethereum.sol';
import {AaveV2Polygon} from './AaveV2Polygon.sol';
import {AaveV2Fuji} from './AaveV2Fuji.sol';
import {AaveV2Avalanche} from './AaveV2Avalanche.sol';
import {AaveV3Ethereum} from './AaveV3Ethereum.sol';
import {AaveV3Sepolia} from './AaveV3Sepolia.sol';
import {AaveV3Polygon} from './AaveV3Polygon.sol';
import {AaveV3Avalanche} from './AaveV3Avalanche.sol';
import {AaveV3Fuji} from './AaveV3Fuji.sol';
import {AaveV3Base} from './AaveV3Base.sol';
import {AaveV3BaseSepolia} from './AaveV3BaseSepolia.sol';
import {AaveV3BaseSepoliaLido} from './AaveV3BaseSepoliaLido.sol';
import {AaveV3Metis} from './AaveV3Metis.sol';
import {AaveV3Gnosis} from './AaveV3Gnosis.sol';
import {AaveV3BNB} from './AaveV3BNB.sol';
import {AaveV3Arbitrum} from './AaveV3Arbitrum.sol';
import {AaveV3ArbitrumSepolia} from './AaveV3ArbitrumSepolia.sol';
import {AaveV3Optimism} from './AaveV3Optimism.sol';
import {AaveV3OptimismSepolia} from './AaveV3OptimismSepolia.sol';
import {AaveV3Scroll} from './AaveV3Scroll.sol';
import {AaveV3ScrollSepolia} from './AaveV3ScrollSepolia.sol';
import {AaveV3ZkSync} from './AaveV3ZkSync.sol';
import {AaveV3FantomTestnet} from './AaveV3FantomTestnet.sol';
import {AaveV3Fantom} from './AaveV3Fantom.sol';
import {AaveV3Harmony} from './AaveV3Harmony.sol';
import {AaveV3EthereumLido} from './AaveV3EthereumLido.sol';
import {AaveV3EthereumEtherFi} from './AaveV3EthereumEtherFi.sol';
import {MiscArbitrum} from './MiscArbitrum.sol';
import {MiscArbitrumSepolia} from './MiscArbitrumSepolia.sol';
import {MiscAvalanche} from './MiscAvalanche.sol';
import {MiscFuji} from './MiscFuji.sol';
import {MiscBase} from './MiscBase.sol';
import {MiscBaseSepolia} from './MiscBaseSepolia.sol';
import {MiscEthereum} from './MiscEthereum.sol';
import {MiscFantom} from './MiscFantom.sol';
import {MiscOptimism} from './MiscOptimism.sol';
import {MiscOptimismSepolia} from './MiscOptimismSepolia.sol';
import {MiscPolygon} from './MiscPolygon.sol';
import {MiscMetis} from './MiscMetis.sol';
import {MiscGnosis} from './MiscGnosis.sol';
import {MiscBNB} from './MiscBNB.sol';
import {MiscScroll} from './MiscScroll.sol';
import {MiscPolygonZkEvm} from './MiscPolygonZkEvm.sol';
import {MiscSepolia} from './MiscSepolia.sol';
import {MiscZkSync} from './MiscZkSync.sol';
import {AaveGovernanceV2} from './AaveGovernanceV2.sol';
import {AaveSafetyModule} from './AaveSafetyModule.sol';
