// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
import {IGovernanceCore, IPayloadsControllerCore, IDataWarehouse, IVotingStrategy} from './GovernanceV3.sol';

library GovernanceV3Binance {
  // https://bscscan.com/address/0x9d33ee6543C9b2C8c183b8fb58fB089266cffA19
  address internal constant CROSS_CHAIN_CONTROLLER = 0x9d33ee6543C9b2C8c183b8fb58fB089266cffA19;

  // https://bscscan.com/address/0xcabb46FfB38c93348Df16558DF156e9f68F9F7F1
  address internal constant CL_EMERGENCY_ORACLE = 0xcabb46FfB38c93348Df16558DF156e9f68F9F7F1;

  // https://bscscan.com/address/0xE5EF2Dd06755A97e975f7E282f828224F2C3e627
  IPayloadsControllerCore internal constant PAYLOADS_CONTROLLER =
    IPayloadsControllerCore(0xE5EF2Dd06755A97e975f7E282f828224F2C3e627);

  // https://bscscan.com/address/0xE3B770Dc4ae3f8bECaB3Ed12dE692c741603e16A
  address internal constant PC_DATA_HELPER = 0xE3B770Dc4ae3f8bECaB3Ed12dE692c741603e16A;

  // https://bscscan.com/address/0x9390B1735def18560c509E2d0bc090E9d6BA257a
  address internal constant EXECUTOR_LVL_1 = 0x9390B1735def18560c509E2d0bc090E9d6BA257a;

  // https://bscscan.com/address/0x0000000000000000000000000000000000000000
  address internal constant EXECUTOR_LVL_2 = 0x0000000000000000000000000000000000000000;
}
