// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// SPDX-License-Identifier: MIT
pragma solidity >=0.6.0;

library MiscArbitrumSepolia {
  // https://sepolia.arbiscan.io/address/0x43A8B7eC945a12a3Acb127B77ede19bd73ad76f8
  address internal constant TRANSPARENT_PROXY_FACTORY = 0x43A8B7eC945a12a3Acb127B77ede19bd73ad76f8;

  // https://sepolia.arbiscan.io/address/0xCB5B3ca20603231945dC5731C33E7f7F7679Ea89
  address internal constant PROXY_ADMIN = 0xCB5B3ca20603231945dC5731C33E7f7F7679Ea89;

  // https://sepolia.arbiscan.io/address/0xb13Cfa6f8B2Eed2C37fB00fF0c1A59807C585810
  address internal constant GHO_TOKEN = 0xb13Cfa6f8B2Eed2C37fB00fF0c1A59807C585810;
}
