// https://snowtrace.io/address/0x27FC7D54C893dA63C0AE6d57e1B2B13A70690928
export const CROSS_CHAIN_CONTROLLER = '0x27FC7D54C893dA63C0AE6d57e1B2B13A70690928';

// https://snowtrace.io/address/0x41185495Bc8297a65DC46f94001DC7233775EbEe
export const CL_EMERGENCY_ORACLE = '0x41185495Bc8297a65DC46f94001DC7233775EbEe';

// https://snowtrace.io/address/0x9b6f5ef589A3DD08670Dd146C11C4Fb33E04494F
export const VOTING_MACHINE = '0x9b6f5ef589A3DD08670Dd146C11C4Fb33E04494F';

// IPayloadsControllerCore https://snowtrace.io/address/0x1140CB7CAfAcC745771C2Ea31e7B5C653c5d0B80
export const PAYLOADS_CONTROLLER = '0x1140CB7CAfAcC745771C2Ea31e7B5C653c5d0B80';

// https://snowtrace.io/address/0xE3B770Dc4ae3f8bECaB3Ed12dE692c741603e16A
export const PC_DATA_HELPER = '0xE3B770Dc4ae3f8bECaB3Ed12dE692c741603e16A';

// https://snowtrace.io/address/0x77976B51569896523EE215962Ee91ff236Fa50E8
export const VM_DATA_HELPER = '0x77976B51569896523EE215962Ee91ff236Fa50E8';

// https://snowtrace.io/address/0xc1162BCb2E5E3ca4725512008c7522dF8C8B7B65
export const GRANULAR_GUARDIAN = '0xc1162BCb2E5E3ca4725512008c7522dF8C8B7B65';

// https://snowtrace.io/address/0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe
export const GOVERNANCE_GUARDIAN = '0x360c0a69Ed2912351227a0b745f890CB2eBDbcFe';

// https://snowtrace.io/address/0x3C06dce358add17aAf230f2234bCCC4afd50d090
export const EXECUTOR_LVL_1 = '0x3C06dce358add17aAf230f2234bCCC4afd50d090';

// IVotingStrategy https://snowtrace.io/address/0x690C218668B440204F369Af1541245d367cc805C
export const VOTING_STRATEGY = '0x690C218668B440204F369Af1541245d367cc805C';

// IDataWarehouse https://snowtrace.io/address/0x9626F9d60CC0B7e1c9a0A47b7f0bd618fb6f40ff
export const DATA_WAREHOUSE = '0x9626F9d60CC0B7e1c9a0A47b7f0bd618fb6f40ff';

export const CHAIN_ID = 43114;
