// AUTOGENERATED - MANUALLY CHANGES WILL BE REVERTED BY THE GENERATOR
// https://optimistic.etherscan.io/address/0x9abf798f5314BFd793A9E57A654BEd35af4A1D60
export const PARASWAP_FEE_CLAIMER = '0x9abf798f5314BFd793A9E57A654BEd35af4A1D60';

// https://optimistic.etherscan.io/address/0xB4e496f70602fE2AC6Ae511D028BA4D194773B29
export const TRANSPARENT_PROXY_FACTORY = '0xB4e496f70602fE2AC6Ae511D028BA4D194773B29';

// https://optimistic.etherscan.io/address/0xD3cF979e676265e4f6379749DECe4708B9A22476
export const PROXY_ADMIN = '0xD3cF979e676265e4f6379749DECe4708B9A22476';

// https://optimistic.etherscan.io/address/0x3b56998Ec06477704622ca8e2eA1b4db134cec32
export const CREATE_3_FACTORY = '0x3b56998Ec06477704622ca8e2eA1b4db134cec32';

// https://optimistic.etherscan.io/address/0x55Cf9583D7D30DC4936bAee1f747591dBECe5df7
export const AAVE_CL_ROBOT_OPERATOR = '0x55Cf9583D7D30DC4936bAee1f747591dBECe5df7';

// https://optimistic.etherscan.io/address/0x56C1a4b54921DEA9A344967a8693C7E661D72968
export const PROTOCOL_GUARDIAN = '0x56C1a4b54921DEA9A344967a8693C7E661D72968';

// https://optimistic.etherscan.io/address/0x1685D81212580DD4cDA287616C2f6F4794927e18
export const AAVE_MERKLE_DISTRIBUTOR = '0x1685D81212580DD4cDA287616C2f6F4794927e18';

// https://optimistic.etherscan.io/address/0xe59EBa0D492cA53C6f46015EEa00517F2707dc77
export const wstETH_stETH_AGGREGATOR = '0xe59EBa0D492cA53C6f46015EEa00517F2707dc77';

// https://optimistic.etherscan.io/address/0x22F3727be377781d1579B7C9222382b21c9d1a8f
export const rETH_ETH_AGGREGATOR = '0x22F3727be377781d1579B7C9222382b21c9d1a8f';

// https://optimistic.etherscan.io/address/0x7d9103572bE58FfE99dc390E8246f02dcAe6f611
export const LEGACY_BRIDGE_EXECUTOR = '0x7d9103572bE58FfE99dc390E8246f02dcAe6f611';

export const CHAIN_ID = 10;
